@@ -1,12 +1,10 @@
 """
-EdbSiwave Class
--------------------
-
-This class manages Edb Siwave and related methods
-
-
+This module contains these clases: `CircuitPort`, `CurrentSource`, `EdbSiwave`, 
+`PinGroup`, `ResistorSource`, `Source`, `SourceType`, and `VoltageSource`.
 """
+
 import warnings
+import os
 from .general import *
 from ..generic.general_methods import get_filename_without_extension, generate_unique_name
 
@@ -20,10 +18,12 @@ except ImportError:
 
 
 class SourceType(object):
+    """Manages source types."""
     (Port, CurrentSource, VoltageSource, Resistor) = (1, 2, 3, 4)
 
 
-class PinGroup():
+class PinGroup(object):
+    """Manages pin groups.""" 
     def __init__(self):
         self._name = ""
         self._component = ""
@@ -32,6 +32,7 @@ class PinGroup():
 
     @property
     def name(self):
+        """Name."""
         return self._name
 
     @name.setter
@@ -40,14 +41,16 @@ class PinGroup():
 
     @property
     def component(self):
+        """Component."""
         return self._component
 
     @component.setter
-    def component_mode(self, value):
+    def component(self, value):
         self._component = value
 
     @property
     def node_pins(self):
+        """Node pins."""
         return self._node_pins
 
     @node_pins.setter
@@ -56,13 +59,17 @@ class PinGroup():
 
     @property
     def net(self):
+        """Net."""
         return self._net
 
     @net.setter
     def net(self, value):
         self._net = value
 
-class Source():
+
+class Source(object):
+    """Manages sources."""
+
     def __init__(self):
         self._name = ""
         self._type = SourceType.Port
@@ -72,6 +79,7 @@ class Source():
 
     @property
     def name(self):
+        """Name."""
         return self._name
 
     @name.setter
@@ -80,6 +88,7 @@ class Source():
 
     @property
     def type(self):
+        """Type."""
         return self._type
 
     @type.setter
@@ -88,6 +97,7 @@ class Source():
 
     @property
     def positive_node(self):
+        """Positive node."""
         return self._positive_node
 
     @positive_node.setter
@@ -96,6 +106,7 @@ class Source():
 
     @property
     def negative_node(self):
+        """Negative node."""
         return self._negative_node
 
     @negative_node.setter
@@ -104,20 +115,24 @@ class Source():
 
     @property
     def do_pin_grouping(self):
+        """Do pin groupings."""
         return self._do_pin_grouping
 
     @do_pin_grouping.setter
     def do_pin_grouping(self,value):
         self._do_pin_grouping = value
 
+
 class CircuitPort(Source):
+    """Manages a circuit port."""
     def __init(self):
-        super().__init__()
+        super(CircuitPort, self).__init__()
         self._impedance = "50"
         self._type = SourceType.Port
 
     @property
     def impedance(self):
+        """Impedance."""
         return self._impedance
 
     @impedance.setter
@@ -126,11 +141,14 @@ class CircuitPort(Source):
 
     @property
     def get_type(self):
+        """Get type."""
         return self.type
 
+
 class VoltageSource(Source):
+    """Manages a voltage source."""
     def __init__(self):
-        super().__init__()
+        super(VoltageSource, self).__init__()
         self._magnitude = "1V"
         self._phase = "0Deg"
         self._impedance = "0.05"
@@ -138,6 +156,7 @@ class VoltageSource(Source):
 
     @property
     def magnitude(self):
+        """Magnitude."""
         return  self._magnitude
 
     @magnitude.setter
@@ -146,6 +165,7 @@ class VoltageSource(Source):
 
     @property
     def phase(self):
+        """Phase."""
         return self._phase
 
     @phase.setter
@@ -154,6 +174,7 @@ class VoltageSource(Source):
 
     @property
     def impedance(self):
+        """Impedance."""
         return self._impedance
 
     @impedance.setter
@@ -162,11 +183,14 @@ class VoltageSource(Source):
 
     @property
     def source_type(self):
+        """Source type."""
         return self.source_type
 
+
 class CurrentSource(Source):
+    """Manages a current source."""
     def __init__(self):
-        super().__init__()
+        super(CurrentSource, self).__init__()
         self._magnitude = "0.1A"
         self._phase = "0Deg"
         self._impedance = "1e7"
@@ -174,6 +198,7 @@ class CurrentSource(Source):
 
     @property
     def magnitude(self):
+        """Magnitude."""
         return  self._magnitude
 
     @magnitude.setter
@@ -182,6 +207,7 @@ class CurrentSource(Source):
 
     @property
     def phase(self):
+        """Phase."""
         return self._phase
 
     @phase.setter
@@ -190,6 +216,7 @@ class CurrentSource(Source):
 
     @property
     def impedance(self):
+        """Impedance."""
         return self._impedance
 
     @impedance.setter
@@ -198,16 +225,20 @@ class CurrentSource(Source):
 
     @property
     def source_type(self):
+        """Source type."""
         return self.source_type
 
+
 class ResistorSource(Source):
+    """Manages a resistor source."""
     def __init__(self):
-        super().__init__()
+        super(ResistorSource, self).__init__()
         self._rvalue = "50"
         self._type = SourceType.Resistor
 
     @property
     def rvalue(self):
+        """Resistance value."""
         return  self._rvalue
 
     @rvalue.setter
@@ -216,78 +247,108 @@ class ResistorSource(Source):
 
     @property
     def source_type(self):
+        """Source type."""
         return self.source_type
 
-class EdBSiwave(object):
-    """EdbSiwave Object"""
+
+class EdbSiwave(object):
+    """Manages EDB functionalities for SIwave.
+
+    Parameters
+    ----------
+    parent :
+        Inherited parent object.
+        
+    Examples
+    --------
+    >>> from pyaedt import Edb
+    >>> edbapp = Edb("myaedbfolder", "project name", "release version")
+    >>> edbapp.core_siwave
+
+    """
+
+    def __init__(self, parent):
+        self.parent = parent
 
     @property
-    def siwave_source(self):
-        """ """
+    def _siwave_source(self):
+        """SIwave source."""
         return self.parent.edblib.SIwave.SiwaveSourceMethods
 
     @property
-    def siwave_setup(self):
-        """ """
+    def _siwave_setup(self):
+        """SIwave setup."""
         return self.parent.edblib.SIwave.SiwaveSimulationSetupMethods
 
     @property
-    def builder(self):
-        """ """
+    def _builder(self):
+        """Builder."""
         return self.parent.builder
 
     @property
-    def edb(self):
-        """ """
+    def _edb(self):
+        """EDB."""
         return self.parent.edb
 
     @property
-    def active_layout(self):
-        """ """
+    def _active_layout(self):
+        """Active layout."""
         return self.parent.active_layout
 
     @property
-    def cell(self):
-        """ """
+    def _cell(self):
+        """Cell."""
         return self.parent.cell
 
     @property
-    def db(self):
+    def _db(self):
         """ """
         return self.parent.db
 
 
-    def __init__(self, parent):
-        self.parent =parent
-
     @aedt_exception_handler
     def create_circuit_port(self, positive_component_name, positive_net_name, negative_component_name=None,
                               negative_net_name="GND", impedance_value=50, port_name=""):
-        """
-        Create a  Circuit Port
+        """Create a circuit port.
+        
+        Parameters
+        ----------
+        positive_component_name : str
+            Name of the positive component.
+        positive_net_name : str
+            Name of the positive net.
+        negative_component_name : str, optional
+            Name of the negative component. The default is ``None``, in which case the name of 
+            the positive net is assigned.
+        negative_net_name : str, optional
+            Name of the negative net name. The default is ``"GND"``.
+        impedance_value : float, optional
+            Port impedance value. The default is ``50``.
+        port_name: str, optional
+            Name of the port. The default is ``""``.
+        
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
 
-        :example:
+        Examples
+        --------
 
-        >>> from AEDTLib.EDB import EDB
-        >>> edbapp = EDB("myaedbfolder", "project name", "release version")
+        >>> from pyaedt import Edb
+        >>> edbapp = Edb("myaedbfolder", "project name", "release version")
         >>> edbapp.core_siwave.create_circuit_port("U2A5","V1P5_S3","U2A5","GND",50,"port_name")
-
-        :param positive_component_name: Name of the positive component
-        :param positive_net_name: Name of positive net name
-        :param negative_component_name:  Name of the negative component. if None, it will be the positive name
-        :param negative_net_name: Name of negative net name
-        :param impedance_value: port impedance value
-        :param port_name: optional port name
-        :return: Bool
         """
         circuit_port = CircuitPort()
         circuit_port.positive_node.net = positive_net_name
         circuit_port.negative_node.net = negative_net_name
         circuit_port.impedance = impedance_value
+        if not negative_component_name:
+            negative_component_name = positive_component_name
         pos_node_cmp = self.parent.core_components.get_component_by_name(positive_component_name)
         neg_node_cmp = self.parent.core_components.get_component_by_name(negative_component_name)
-        pos_node_pins = self.parent.core_components.get_pin_from_component(positive_component_name,positive_net_name)
-        neg_node_pins = self.parent.core_components.get_pin_from_component(negative_component_name,negative_net_name)
+        pos_node_pins = self.parent.core_components.get_pin_from_component(positive_component_name, positive_net_name)
+        neg_node_pins = self.parent.core_components.get_pin_from_component(negative_component_name, negative_net_name)
 
 
         if port_name == "":
@@ -304,22 +365,37 @@ class EdBSiwave(object):
     @aedt_exception_handler
     def create_voltage_source(self, positive_component_name, positive_net_name, negative_component_name=None,
                               negative_net_name="GND", voltage_value=3.3, phase_value=0,source_name=""):
-        """Create a Voltage Source
+        """Create a voltage source.
+        
+        Parameters
+        ----------
+        positive_component_name : str
+            Name of the positive component.
+        positive_net_name : str
+            Name of the positive net.
+        negative_component_name : str, optional 
+            Name of the negative component. The default is ``None``, in which case the name of 
+            the positive net is assigned.
+        negative_net_name : str, optional
+            Name of the negative net. The default is ``"GND"``.
+        voltage_value : float, optional
+            Value for the voltage. The default is ``3.3``.
+        phase_value : optional
+            Value for the phase. The default is ``0``.
+        source_name : str, optional
+            Name of the source. The default is ``""``.
+        
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+            
+        Examples
+        --------
 
-        :example:
-
-        >>> from AEDTLib.EDB import EDB
-        >>> edbapp = EDB("myaedbfolder", "project name", "release version")
+        >>> from pyaedt import Edb
+        >>> edbapp = Edb("myaedbfolder", "project name", "release version")
         >>> edb.core_siwave.create_voltage_source("U2A5","V1P5_S3","U2A5","GND",3.3,0,"source_name")
-
-        :param positive_component_name: Name of the positive component
-        :param positive_net_name: Name of positive net name
-        :param negative_component_name:  Name of the negative component. if None, it will be the positive name
-        :param negative_net_name: Name of negative net name
-        :param current_value: Voltage Value
-        :param phase_value: Optional Phase Value
-        :param source_name: optional port name
-        :return: Bool
         """
         voltage_source = VoltageSource()
         voltage_source.positive_node.net = positive_net_name
@@ -332,7 +408,7 @@ class EdBSiwave(object):
         neg_node_pins = self.parent.core_components.get_pin_from_component(negative_component_name, negative_net_name)
 
         if source_name == "":
-            source_name = "Port_{}_{}_{}_{}".format(positive_component_name, positive_net_name, negative_component_name,
+            source_name = "Vsource_{}_{}_{}_{}".format(positive_component_name, positive_net_name, negative_component_name,
                                                   negative_net_name)
         voltage_source.name = source_name
         voltage_source.positive_node.component_node = pos_node_cmp
@@ -345,20 +421,37 @@ class EdBSiwave(object):
     @aedt_exception_handler
     def create_current_source(self, positive_component_name, positive_net_name, negative_component_name=None,
                               negative_net_name="GND", current_value=0.1, phase_value=0, source_name=""):
-        """Create a Current Source
+        """Create a current source.
+        
+        Parameters
+        ----------
+        positive_component_name : str
+            Name of the positive component.
+        positive_net_name : str
+            Name of the positive net.
+        negative_component_name : str, optional 
+            Name of the negative component. The default is ``None``, in which case the name of 
+            the positive net is assigned.
+        negative_net_name : str, optional
+            Name of the negative net. The default is ``"GND"``.
+        current_value : float, optional
+            Value for the current. The default is ``0.1``.
+        phase_value: optional
+            Value for the phase. The default is ``0``.
+        source_name : str, optional
+            Name of the source. The default is ``""``.
+        
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+        
+        Examples
+        --------
 
-        >>> from AEDTLib.EDB import EDB
-        >>> edbapp = EDB("myaedbfolder", "project name", "release version")
-        >>> edb.core_siwave.create_current_source("U2A5","V1P5_S3","U2A5","GND",0.1,0,"source_name")
-
-        :param positive_component_name: Name of the positive component
-        :param positive_net_name: Name of positive net name
-        :param negative_component_name:  Name of the negative component. if None, it will be the positive name
-        :param negative_net_name: Name of negative net name
-        :param current_value: Current Value
-        :param phase_value: Optional Phase Value
-        :param source_name: optional source name
-        :return: Bool
+        >>> from pyaedt import Edb
+        >>> edbapp = Edb("myaedbfolder", "project name", "release version")
+        >>> edb.core_siwave.create_current_source("U2A5","V1P5_S3","U2A5","GND",0.1,0,"source_name")   
         """
         current_source = CurrentSource()
         current_source.positive_node.net = positive_net_name
@@ -384,20 +477,35 @@ class EdBSiwave(object):
     @aedt_exception_handler
     def create_resistor(self, positive_component_name, positive_net_name, negative_component_name=None,
                               negative_net_name="GND", rvalue=1, resistor_name=""):
-        """Create a Voltage Source
-
-        >>> from AEDTLib.EDB import EDB
-        >>> edbapp = EDB("myaedbfolder", "project name", "release version")
-        >>> edb.core_siwave.create_resistor("U2A5","V1P5_S3","U2A5","GND",1,"resistor_name")
-
-        :param positive_component_name: Name of the positive component
-        :param positive_net_name: Name of positive net name
-        :param negative_component_name:  Name of the negative component. if None, it will be the positive name
-        :param negative_net_name: Name of negative net name
-        :param current_value: Current Value
-        :param phase_value: Optional Phase Value
-        :param source_name: optional source name
-        :return: Bool
+        """Create a voltage source.
+        
+        Parameters
+        ----------
+        positive_component_name : str
+            Name of the positive component.
+        positive_net_name : str
+            Name of the positive net.
+        negative_component_name : str, optional 
+            Name of the negative component. The default is ``None``, in which case the name of 
+            the positive net is assigned.
+        negative_net_name : str, optional
+            Name of the negative net. The default is ``"GND"``.
+        rvalue : float, optional
+            Resistance value. The default is ``1``.
+        resistor_name : str, optional
+            Name of the resistor. The default is ``""``.
+        
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+        
+        Examples
+        --------
+        
+        >>> from pyaedt import Edb
+        >>> edbapp = Edb("myaedbfolder", "project name", "release version")
+        >>> edb.core_siwave.create_resistor("U2A5", "V1P5_S3", "U2A5", "GND", 1, "resistor_name")        
         """
         resistor = ResistorSource()
         resistor.positive_node.net = positive_net_name
@@ -420,87 +528,156 @@ class EdBSiwave(object):
         return True
 
     @aedt_exception_handler
-    def add_siwave_ac_analysis(self, accuracy_level=1, decade_count=10, sweeptype=1, start_freq=1, stop_freq=1e9, step_freq=1e6, discre_sweep=False):
-        """
-        Add Siwave AC Analysis
+    def create_exec_file(self):
+        """Create an executable file."""
+        workdir = os.path.dirname(self.parent.edbpath)
+        file_name = os.path.join(workdir,os.path.splitext(os.path.basename(self.parent.edbpath))[0] + '.exec')
+        if os.path.isfile(file_name):
+            os.remove(file_name)
+        f = open(file_name,"w")
+        return f
 
+    @aedt_exception_handler
+    def add_siwave_ac_analysis(self, accuracy_level=1, decade_count=10, sweeptype=1, start_freq=1, stop_freq=1e9, step_freq=1e6, discrete_sweep=False):
+        """Add a SIwave AC analysis to EDB.
 
-        :param accuracy_level:
-        :param decade_count:
-        :param sweeptype:
-        :param start_freq:
-        :param stop_freq:
-        :param step_freq:
-        :param discre_sweep:
-        :return:
+        Parameters
+        ----------
+        accuracy_level : int, optional
+           Level of accuracy. The default is ``1``.
+        decade_count : int
+            The default is ``10``.    
+        sweeptype : int, optional
+            Type of the sweep. The default is ``1``.
+        start_freq : float, optional
+            Starting frequency. The default is ``1``. 
+        stop_freq : float, optional
+            Stopping frequency. The default is ``1e9``.
+        step_freq : float, optional
+            Frequency size of the step. The default is ``1e6``.
+        discrete_sweep: bool, optonal
+            Whether the sweep is discrete. The default is ``False``.
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.  
         """
-        self.siwave_setup.AddACSimSetup(self.builder, accuracy_level, str(decade_count), sweeptype, str(start_freq), str(stop_freq), str(step_freq), discre_sweep)
+        self._siwave_setup.AddACSimSetup(self._builder, accuracy_level, str(decade_count), sweeptype, str(start_freq), str(stop_freq), str(step_freq), discrete_sweep)
+        exec_file = self.create_exec_file()
+        exec_file.write("ExecAcSim\n")
+        exec_file.close()
+        return True
+
+    @aedt_exception_handler
+    def add_siwave_syz_analysis(self, accuracy_level=1, decade_count=10, sweeptype=1, start_freq=1, stop_freq=1e9,
+                               step_freq=1e6, discrete_sweep=False):
+        """Add a SIwave SYZ analysis.
+
+        Parameters
+        ----------
+        accuracy_level : int, optional
+           Level of accuracy. The default is ``1``.
+        decade_count : int, optional
+            Number of points to calculate in each decade. The default is ``10``.    
+        sweeptype : int, optional
+            Type of the sweep. The default is ``1``.
+        start_freq : float, optional
+            Starting frequency. The default is ``1``. 
+        stop_freq : float, optional
+            Stopping frequency. The default is ``1e9``.
+        step_freq : float, optional
+            Frequency size of the step. The default is ``1e6``.
+        discrete_sweep: bool, optonal
+            Whether the sweep is discrete. The default is ``False``.
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.       
+        """
+
+        self._siwave_setup.AddSYZSimSetup(self._builder, accuracy_level, str(decade_count), sweeptype, str(start_freq),
+                                        str(stop_freq), str(step_freq), discrete_sweep)
+        exec_file = self.create_exec_file()
+        exec_file.write("ExecSyzSim\n")
+        exec_file.write("SaveSiw\n")
+        exec_file.close()
         return True
 
     @aedt_exception_handler
     def add_siwave_dc_analysis(self, accuracy_level=1):
-        """Add Siwave DC Analysis
+        """Add a SIwave DC analysis.
 
         Parameters
         ----------
-        accuracy_level :
-            Accuracy Level (Default value = 1)
+        accuracy_level : int, optional
+            Level of accuracy. The default is ``1``.
 
         Returns
         -------
-        type
-            Bool
-
+        bool
+            ``True`` when successful, ``False`` when failed.
         """
-
-        self.siwave_setup.AddDCSimSetup(self.builder, accuracy_level)
+        self._siwave_setup.AddDCSimSetup(self._builder, accuracy_level)
+        exec_file = self.create_exec_file()
+        exec_file.write("ExecDcSim\n")
+        exec_file.close()
         return True
 
     @aedt_exception_handler
     def create_pin_group_terminal(self, source):
+        """Create a pin group terminal.
+        
+        Parameters
+        ----------
+        source : str
+            Name of the source.
+        
+        """
         pos_pin_group = self.parent.core_components.create_pingroup_from_pins(source.positive_node.node_pins)
-        neg_pin_group = self.parent.core_components.create_pingroup_from_pins(source._negative_node.node_pins)
+        neg_pin_group = self.parent.core_components.create_pingroup_from_pins(source.negative_node.node_pins)
         pos_node_net = self.parent.core_nets.get_net_by_name(source.positive_node.net)
         neg_node_net = self.parent.core_nets.get_net_by_name(source.negative_node.net)
         pos_pingroup_term_name = "{}_{}".format(source.positive_node.net,source.name)
         neg_pingroup_term_name = "{}_{}".format(source.negative_node.net,source.name)
-        pos_pingroup_terminal = self.edb.Cell.Terminal.PinGroupTerminal.Create(self.active_layout,pos_node_net,pos_pingroup_term_name , pos_pin_group[1], False)
-        neg_pingroup_terminal = self.edb.Cell.Terminal.PinGroupTerminal.Create(self.active_layout,neg_node_net,neg_pingroup_term_name , neg_pin_group[1], False)
+        pos_pingroup_terminal = self._edb.Cell.Terminal.PinGroupTerminal.Create(self._active_layout,pos_node_net,pos_pingroup_term_name , pos_pin_group[1], False)
+        neg_pingroup_terminal = self._edb.Cell.Terminal.PinGroupTerminal.Create(self._active_layout,neg_node_net,neg_pingroup_term_name , neg_pin_group[1], False)
 
         if source.type == SourceType.Port:
-            pos_pingroup_terminal.SetBoundaryType(self.edb.Cell.Terminal.BoundaryType.PortBoundary)
-            neg_pingroup_terminal.SetBoundaryType(self.edb.Cell.Terminal.BoundaryType.PortBoundary)
-            pos_pingroup_terminal.SetSourceAmplitude(self.edb.Utility.Value(source.impedance))
+            pos_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.PortBoundary)
+            neg_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.PortBoundary)
+            pos_pingroup_terminal.SetSourceAmplitude(self._edb.Utility.Value(source.impedance))
             pos_pingroup_terminal.SetIsCircuitPort(True)
             neg_pingroup_terminal.SetIsCircuitPort(True)
             pos_pingroup_terminal.SetReferenceTerminal(neg_pingroup_terminal)
 
         elif source.type == SourceType.CurrentSource:
-            pos_pingroup_terminal.SetBoundaryType(self.edb.Cell.Terminal.BoundaryType.kCurrentSource)
-            neg_pingroup_terminal.SetBoundaryType(self.edb.Cell.Terminal.BoundaryType.kCurrentSource)
-            pos_pingroup_terminal.SetSourceAmplitude(self.edb.Utility.Value(source.magnitude))
-            pos_pingroup_terminal.SetSourcePhase(self.edb.Utility.Value(source.phase))
+            pos_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.kCurrentSource)
+            neg_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.kCurrentSource)
+            pos_pingroup_terminal.SetSourceAmplitude(self._edb.Utility.Value(source.magnitude))
+            pos_pingroup_terminal.SetSourcePhase(self._edb.Utility.Value(source.phase))
             pos_pingroup_terminal.SetIsCircuitPort(True)
             neg_pingroup_terminal.SetIsCircuitPort(True)
             pos_pingroup_terminal.SetReferenceTerminal(neg_pingroup_terminal)
 
         elif source.type == SourceType.VoltageSource:
-            pos_pingroup_terminal.SetBoundaryType(self.edb.Cell.Terminal.BoundaryType.kVoltageSource)
-            neg_pingroup_terminal.SetBoundaryType(self.edb.Cell.Terminal.BoundaryType.kVoltageSource)
-            pos_pingroup_terminal.SetSourceAmplitude(self.edb.Utility.Value(source.magnitude))
-            pos_pingroup_terminal.SetSourcePhase(self.edb.Utility.Value(source.phase))
+            pos_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.kVoltageSource)
+            neg_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.kVoltageSource)
+            pos_pingroup_terminal.SetSourceAmplitude(self._edb.Utility.Value(source.magnitude))
+            pos_pingroup_terminal.SetSourcePhase(self._edb.Utility.Value(source.phase))
             pos_pingroup_terminal.SetIsCircuitPort(True)
             neg_pingroup_terminal.SetIsCircuitPort(True)
             pos_pingroup_terminal.SetReferenceTerminal(neg_pingroup_terminal)
 
         elif source.type == SourceType.Resistor:
-            pos_pingroup_terminal.SetBoundaryType(self.edb.Cell.Terminal.BoundaryType.RlcBoundary)
-            neg_pingroup_terminal.SetBoundaryType(self.edb.Cell.Terminal.BoundaryType.RlcBoundary)
+            pos_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.RlcBoundary)
+            neg_pingroup_terminal.SetBoundaryType(self._edb.Cell.Terminal.BoundaryType.RlcBoundary)
             pos_pingroup_terminal.SetReferenceTerminal(neg_pingroup_terminal)
-            pos_pingroup_terminal.SetSourceAmplitude(self.edb.Utility.Value(source.rvalue))
+            pos_pingroup_terminal.SetSourceAmplitude(self._edb.Utility.Value(source.rvalue))
             pos_pingroup_terminal.SetIsCircuitPort(True)
             neg_pingroup_terminal.SetIsCircuitPort(True)
-            Rlc = self.edb.Utility.Rlc()
+            Rlc = self._edb.Utility.Rlc()
             Rlc.CEnabled = False
             Rlc.LEnabled = False
             Rlc.REnabled = True
