@@ -1,11 +1,19 @@
 """Download example datasets from https://github.com/pyansys/example-data"""
 import shutil
 import os
-import urllib.request
-
+import sys
+if "IronPython" in sys.version or ".NETFramework" in sys.version:
+    import urllib
+else:
+    import urllib.request
 from pyaedt.generic.general_methods import  generate_unique_name
 EXAMPLE_REPO = 'https://github.com/pyansys/example-data/raw/master/pyaedt/'
-EXAMPLES_PATH = os.path.join(os.environ["TEMP"], "PyAEDTExamples")
+if os.name == "posix":
+    tmpfold = os.environ["TMPDIR"]
+else:
+    tmpfold = os.environ["TEMP"]
+
+EXAMPLES_PATH = os.path.join(tmpfold, "PyAEDTExamples")
 
 
 def delete_downloads():
@@ -29,16 +37,23 @@ def _retrieve_file(url, filename, directory):
         return local_path_no_zip
 
     # grab the correct url retriever
-    urlretrieve = urllib.request.urlretrieve
+    if "IronPython" in sys.version or ".NETFramework" in sys.version:
+        urlretrieve = urllib.urlretrieve
+    else:
+        urlretrieve = urllib.request.urlretrieve
 
     dirpath = os.path.dirname(local_path)
     if not os.path.isdir(EXAMPLES_PATH):
         os.mkdir(EXAMPLES_PATH)
     if not os.path.isdir(dirpath):
-        os.makedirs(dirpath, exist_ok=True)
+        os.makedirs(dirpath)
 
     # Perform download
-    _, resp = urlretrieve(url, local_path)
+    if os.name == "posix":
+        command = "wget {} -O {}".format(url, local_path)
+        os.system(command)
+    else:
+        _, resp = urlretrieve(url, local_path)
     return local_path
 
 
@@ -51,7 +66,7 @@ def _download_file(directory, filename):
 ###############################################################################
 # front-facing functions
 
-def download_aedb() -> str:
+def download_aedb():
     """Download an example of AEDB File and return the def path.
     Examples files are downloaded to a persistent cache to avoid
     re-downloading the same file twice.
@@ -71,7 +86,7 @@ def download_aedb() -> str:
 
     return _download_file('edb/Galileo.aedb', 'edb.def')
 
-def download_netlist() -> str:
+def download_netlist():
     """Download an example of netlist File and return the def path.
     Examples files are downloaded to a persistent cache to avoid
     re-downloading the same file twice.
@@ -90,8 +105,45 @@ def download_netlist() -> str:
 
     return _download_file('netlist', 'netlist_small.cir')
 
+def download_antenna_array():
+    """Download an example of Antenna Array and return the def path.
+    Examples files are downloaded to a persistent cache to avoid
+    re-downloading the same file twice.
+    Returns
+    -------
+    str
+        Path to the example file.
+    Examples
+    --------
+    Download an example result file and return the path of the file
+    >>> from pyaedt import examples
+    >>> path = examples.download_antenna_array()
+    >>> path
+    'C:/Users/user/AppData/local/temp/pyaedtexamples/FiniteArray_Radome_77GHz_3D_CADDM.aedt'
+    """
 
-def download_touchstone() -> str:
+    return _download_file('array_antenna', 'FiniteArray_Radome_77GHz_3D_CADDM.aedt')
+
+def download_sbr():
+    """Download an example of SBR+ Array and return the def path.
+    Examples files are downloaded to a persistent cache to avoid
+    re-downloading the same file twice.
+    Returns
+    -------
+    str
+        Path to the example file.
+    Examples
+    --------
+    Download an example result file and return the path of the file
+    >>> from pyaedt import examples
+    >>> path = examples.download_antenna_array()
+    >>> path
+    'C:/Users/user/AppData/local/temp/pyaedtexamples/FiniteArray_Radome_77GHz_3D_CADDM.aedt'
+    """
+
+    return _download_file('sbr', 'Cassegrain.aedt')
+
+def download_touchstone():
     """Download an example of touchstone File and return the def path.
     Examples files are downloaded to a persistent cache to avoid
     re-downloading the same file twice.
@@ -111,7 +163,7 @@ def download_touchstone() -> str:
     return _download_file('touchstone', 'SSN_ssn.s6p')
 
 
-def download_sherlock() -> str:
+def download_sherlock():
     """Download an example of sherlock needed files and return the def path.
     Examples files are downloaded to a persistent cache to avoid
     re-downloading the same file twice.
