@@ -1,64 +1,47 @@
-"""
-Hfss 3d Layout Class
-----------------------------------------------------------------
-
-This class contains all HFSS 3D Layout functionalities. It inherits all objects that belong to HFSS 3D Layout, including EDB API queries.
-
-
-Examples:
-
-hfss = Hfss3dLayout()     Creates an ``Hfss3dLayout`` object and connects to an existing HFSS design or create a new HFSS design if one is not present.
-
-
-hfss = Hfss3dLayout(projectname)     Creates an ``Hfss3dLayout`` object and links to a project named projectname. If this project doesn't exist, it creates a new one with this name.
-
-
-hfss = Hfss3dLayout(projectname,designame)     Creates an ``Hfss3dLayout`` object and links to a design named designname in a project named projectname.
-
-
-hfss = Hfss3dLayout("myfile.aedt")     Creates an ``Hfss3dLayout object`` and opens the specified project.
-
-
-========================================================
-
-"""
+"""This module contains these classes: `Hfss3dLayout` and `SweepString`."""
 
 from __future__ import absolute_import
 import os
 
 from .application.Analysis3DLayout import FieldAnalysis3DLayout
 from .desktop import exception_to_desktop
-
+from .modules.SolveSetup import Setup3DLayout
 from .generic.general_methods import generate_unique_name, aedt_exception_handler
 
 
 
 class SweepString(object):
-    """generate a sweep string like for examples "LIN 10GHz 20GHz 0.05GHz LINC 20GHz 30GHz 10 DEC 30GHz 40GHz 10 40GHz"""
+    """Generates a sweep string.
+    
+    For example, ``"LIN 10GHz 20GHz 0.05GHz LINC 20GHz 30GHz 10 DEC 30GHz 40GHz 10 40GHz``.
+    
+    Parameters
+    ----------
+    unit : str, optional
+        Units for the sweep string. The default is ``"GHz"``.
+     """
+        
     def __init__(self, unit='GHz'):
-        """
-
-        :param unit:
-        """
+    
         self.unit = unit
         self.sweep_string = ""
 
     @aedt_exception_handler
     def add_sweep(self, sweep, line_type, unit=None):
-        """Add a sweep line to the string
+        """Add a line to the sweep string.
 
         Parameters
         ----------
-        sweep :
-            list of frequencies,
+        sweep : list
+            List of frequencies,
             if linear_step [start, stop, step]
             if linear_count [start, stop, number of steps]
             if log_scale [start, stop, samples]
             if single [f1, f2,... fn]
         line_type :
             linear_step", "linear_count", "log_scale", "single"
-        unit :
-            MHz", "GHz",... (Default value = None)
+        unit : str
+            Units such as ``"MHz"`` or ``"GHz"``. The default is ``None``.
 
         Returns
         -------
@@ -92,54 +75,104 @@ class SweepString(object):
             return None
 
 
-class Hfss3dLayout(FieldAnalysis3DLayout, object):
-    """HFSS 3D Layout Object
+class Hfss3dLayout(FieldAnalysis3DLayout):
+    """HFSS 3D Layout application interface.
+
+    This class inherits all objects that belong to HFSS 3D Layout, including EDB
+    API queries.
 
     Parameters
     ----------
-    projectname :
-        name of the project to be selected or full path to the project to be opened  or to the AEDTZ archive. if None try to get active project and, if nothing present to create an empty one
-    designname :
-        name of the design to be selected. if None, try to get active design and, if nothing present to create an empty one
-    solution_type :
-        solution type to be applied to design. if None default is taken
-    setup_name :
-        setup_name to be used as nominal. if none active setup is taken or nothing
+    projectname : str, optional
+        Name of the project to select or the full path to the project
+        or AEDTZ archive to open.  The default is ``None``, in which
+        case an attempt is made to get an active project. If no 
+        projects are present, an empty project is created.
+    designname : str, optional
+        Name of the design to select. The default is ``None``, in 
+        which case an attempt is made to get an active design. If no
+        designs are present, an empty design is created.
+    solution_type : str, optional
+        Solution type to apply to the design. The default is
+        ``None``, in which case the default type is applied.
+    setup_name : str, optional
+        Name of the setup to use as the nominal. The default is
+        ``None``, in which case the active setup is used or 
+        nothing is used.
+    specified_version : str, optional
+        Version of AEDT to use. The default is ``None``, in which case
+        the active version or latest installed version is used.
+    NG : bool, optional
+        Whether to launch AEDT in the non-graphical mode. The default 
+        is``False``, in which case AEDT is launched in the graphical mode.  
+    AlwaysNew : bool, optional
+        Whether to launch an instance of AEDT in a new thread, even if
+        another instance of the ``specified_version`` is active on the
+        machine. The default is ``True``.
+    release_on_exit : bool, optional
+        Whether to release AEDT on exit. 
+    student_version : bool, optional
+        Whether to open the AEDT student version. The default is ``False``.
 
-    Returns
-    -------
+    Examples
+    --------
+    Create an `Hfss3dLayout` object and connect to an existing HFSS
+    design or create a new HFSS design if one does not exist.
 
+    >>> from pyaedt import Hfss3dLayout
+    >>> aedtapp = Hfss3dLayout()
+
+    Create an `Hfss3dLayout` object and link to a project named
+    ``projectname``. If this project does not exist, create one with
+    this name.
+
+    >>> aedtapp = Hfss3dLayout(projectname)
+
+    Create an `Hfss3dLayout` object and link to a design named
+    ``designname`` in a project named ``projectname``.
+
+    >>> aedtapp = Hfss3dLayout(projectname,designame)
+
+    Create an `Hfss3dLayout` object and open the specified project.
+
+    >>> aedtapp = Hfss3dLayout("myfile.aedt")
+
+    Create an AEDT 2021 R1 object and then create a
+    `Hfss3dLayout` object and open the specified project.
+
+    >>> aedtapp = Hfss3dLayout(specified_version="2021.1", projectname="myfile.aedt")
+    
     """
-
-    def __init__(self, projectname=None, designname=None, solution_type=None, setup_name=None):
+    def __init__(self, projectname=None, designname=None, solution_type=None, setup_name=None,
+                 specified_version=None, NG=False, AlwaysNew=False, release_on_exit=False, student_version=False):
         FieldAnalysis3DLayout.__init__(self, "HFSS 3D Layout Design", projectname, designname, solution_type,
-                                       setup_name)
+                                       setup_name, specified_version, NG, AlwaysNew, release_on_exit, student_version)
 
     def __enter__(self):
         return self
 
     def __exit__(self, ex_type, ex_value, ex_traceback):
-        ''' Push exit up to parent object Design '''
+        """Push exit up to parent object Design."""
         if ex_type:
             exception_to_desktop(self, ex_value, ex_traceback)
 
     @aedt_exception_handler
     def create_edge_port(self, primivitivename, edgenumber, iscircuit=True):
-        """Create a new edge port
+        """Create an edge port.
 
         Parameters
         ----------
-        primivitivename :
-            name of the primitive
+        primivitivename : str
+            Name of the primitive to create the edge port on.
         edgenumber :
-            edge number on which create a port
-        iscircuit :
-            True (Circuit Port) | False (Default value = True)
+            Edge number to create the edge port on.
+        iscircuit : bool, optional
+            Whether the edge port is a circuit port. The default is ``False``.
 
         Returns
         -------
         type
-            Name of the port
+            Name of the port when successful, ``False`` when failed.
 
         """
         listp = self.port_list
@@ -155,34 +188,34 @@ class Hfss3dLayout(FieldAnalysis3DLayout, object):
 
     @aedt_exception_handler
     def create_coax_port(self, vianame, layer, xstart, xend,ystart, yend, archeight=0, arcrad=0, isexternal=True):
-        """Create a new Coax Port
+        """Create a new coax port.
 
         Parameters
         ----------
-        vianame :
-            Name of the Via on which create a new Port
-        layer :
-            layer name
+        vianame : str
+            Name of the via to create the port on.
+        layer : str
+            Name of the layer.
         xstart :
-            x position of pin
-        ystart :
-            y position of pin
+            Starting position of the pin on the X axis.
         xend :
-            x end position of pin
+            Ending position of the pin on the X axis.
+        ystart :
+            Starting position of the pin on the Y axis.
         yend :
-            y end position of pin
-        archeight :
-            arc height (Default value = 0)
-        arcrad :
-            rotation of pin in rad (Default value = 0)
-        isexternal :
-            True (is external pin) | False is internal Pin (Default value = True)
+            Ending postiion of the pin on the Y axis.
+        archeight : float, optional
+            Arc height. The default is ``0``.
+        arcrad : float, optional
+            Rotation of the pin in radians. The default is ``0``.
+        isexternal : bool, optional
+            Whether the pin is external. The default is ``True``.
 
         Returns
         -------
-        type
-            name of the port | False error
-
+        str
+            Name of the port when successful, ``False`` when failed.
+        
         """
         listp = self.port_list
         if type(layer) is str:
@@ -202,28 +235,30 @@ class Hfss3dLayout(FieldAnalysis3DLayout, object):
 
     @aedt_exception_handler
     def create_pin_port(self,name,xpos=0, ypos=0, rotation=0, top_layer=None, bot_layer=None):
-        """Create a new Pin Port
+        """Create a pin port.
 
         Parameters
         ----------
-        name :
-            Name of the Pin Port
-        xpos :
-            x position of pin (Default value = 0)
-        ypos :
-            y position of pin (Default value = 0)
-        rotation :
-            rotation of pin in deg (Default value = 0)
-        top_layer :
-            top layer of pin. if None, it will be automatically assigned to the top (Default value = None)
-        bot_layer :
-            bottom layer of pin. if None, it will be automatically assigned to the bottom (Default value = None)
+        name : str
+            Name of the pin port.
+        xpos : float, optional
+            X-axis position of the pin. The default is ``0``.
+        ypos : float, optional
+            Y-axis position of the pin. The default is ``0``.
+        rotation : float, optional
+            Rotation of the pin in degrees. The default is ``0``.
+        top_layer : str, optional
+            Top layer of the pin. The default is ``None``, in which case the top 
+            layer is assigned automatically.
+        bot_layer : str
+            Bottom layer of the pin. The default is ``None``, in which case the
+            bottom layer is assigned automatically.
 
         Returns
         -------
-        type
-            True
-
+        bool
+            ``True`` when successful, ``False`` when failed.
+        
         """
         self.modeler.layers.refresh_all_layers()
         layers = self.modeler.layers.all_signal_layers
@@ -252,32 +287,36 @@ class Hfss3dLayout(FieldAnalysis3DLayout, object):
 
     @aedt_exception_handler
     def delete_port(self, portname):
-        """
+        """Delete a port.
 
         Parameters
         ----------
-        portname :
-            
+        portname : str
+            Name of the port.          
 
         Returns
         -------
-
+        bool
+            ``True`` when successful, ``False`` when failed.
+        
         """
         self.oexcitation.Delete(portname)
         return True
 
     @aedt_exception_handler
     def import_edb(self, edb_full_path):
-        """
+        """Import EDB.
 
         Parameters
         ----------
-        edb_full_path :
+        edb_full_path : str
+            Full path to EDB.
             
-
         Returns
         -------
-
+        bool
+            ``True`` when successful, ``False`` when failed. 
+        
         """
         oTool = self.odesktop.GetTool("ImportExport")
         oTool.ImportEDB(edb_full_path)
@@ -287,21 +326,21 @@ class Hfss3dLayout(FieldAnalysis3DLayout, object):
 
     @aedt_exception_handler
     def validate_full_design(self, name=None, outputdir=None, ports=None):
-        """Validate the design based on expected value and save infos on log file
+        """Validate the design based on the expected value and save the information in the log file.
 
         Parameters
         ----------
-        name :
-            name of design to validate (Default value = None)
-        outputdir :
-            output dir where to save the log file (Default value = None)
-        ports :
-            number of excitations expected (Default value = None)
+        name : str, optional
+            Name of the design to validate. The default is ``None``.
+        outputdir : str, optional
+            Output directory to save the log file to. The default is ``None``.
+        ports : str, optional
+            Number of excitations that are expected. The default is ``None``.
 
         Returns
         -------
-        type
-            all the info in a list for use later
+        list
+            List of validation messages.
 
         """
         if name is None:
@@ -311,14 +350,14 @@ class Hfss3dLayout(FieldAnalysis3DLayout, object):
 
         self._messenger.add_info_message("#### Design Validation Checks###")
         #
-        # Routine outputs to the validtaion info to a log file in the project directory and also
+        # Routine outputs to the validation info to a log file in the project directory and also
         # returns the validation info to be used to update properties.xml file
 
         validation_ok = True
 
         #
         # Write an overall validation log file with all output from all checks
-        # the design validation inside HFSS outputs to a separate log file which we merge into this overall file
+        # The design validation inside HFSS outputs to a separate log file which we merge into this overall file
         #
         val_list = []
         all_validate = outputdir + "\\all_validation.log"
@@ -382,34 +421,28 @@ class Hfss3dLayout(FieldAnalysis3DLayout, object):
         return val_list, validation_ok  # return all the info in a list for use later
 
     @aedt_exception_handler
-    def create_scattering(self, PlotName="S Parameter Plot Nominal", sweep_name=None, PortNames=None, PortExcited=None, variations=None ):
-        """Create Scattering Report
-        
-        
-        sweeps = design eXploration variations (list of str)
-        PortNames = (list of str)
-        PortExcited = (str)
-        :return:
+    def create_scattering(self, plot_name="S Parameter Plot Nominal", sweep_name=None, port_names=None, port_excited=None, variations=None):
+        """Create a scattering report.
 
         Parameters
         ----------
-        PlotName :
-             (Default value = "S Parameter Plot Nominal")
-        sweep_name :
-             (Default value = None)
-        PortNames :
-             (Default value = None)
-        PortExcited :
-             (Default value = None)
-        variations :
-             (Default value = None)
+        PlotName : str, optional
+             Name of the plot. The default is ``"S Parameter Plot Nominal"``.
+        sweep_name : str, optional
+             Name of the sweep. The default is ``None``.
+        port_names : str or list, optional
+             One or more port names. The default is ``None``.
+        port_excited : optional
+             The default is ``None``.
+        variations : optional
+             The default is ``None``.
 
         Returns
         -------
-
+        bool
+            ``True`` when successful, ``False`` when failed.
+        
         """
-        # set plot name
-        # Setup arguments list for CreateReport function
         Families = ["Freq:=", ["All"]]
         if variations:
             Families +=variations
@@ -417,20 +450,22 @@ class Hfss3dLayout(FieldAnalysis3DLayout, object):
             Families += self.get_nominal_variation()
         if not sweep_name:
             sweep_name = self.existing_analysis_sweeps[1]
-        if not PortNames:
-            PortNames = self.modeler.get_excitations_name()
-        if not PortExcited:
-            PortExcited= PortNames
-        Trace = ["X Component:=", "Freq", "Y Component:=", ["dB(S(" + p + "," + q + "))" for p,q in zip(list(PortNames), list(PortExcited))]]
+        if not port_names:
+            port_names = self.get_excitations_name
+        if not port_excited:
+            port_excited= port_names
+        Trace = ["X Component:=", "Freq", "Y Component:=", ["dB(S(" + p + "," + q + "))" for p,q in zip(list(port_names), list(port_excited))]]
         solution_data = ""
         if self.solution_type == "DrivenModal":
             solution_data = "Modal Solution Data"
         elif self.solution_type == "DrivenTerminal":
             solution_data = "Terminal Solution Data"
+        elif self.solution_type == "HFSS3DLayout":
+            solution_data = "Standard"
         if solution_data != "":
             # run CreateReport function
             self.post.oreportsetup.CreateReport(
-                PlotName,
+                plot_name,
                 solution_data,
                 "Rectangular Plot",
                 sweep_name,
@@ -442,37 +477,29 @@ class Hfss3dLayout(FieldAnalysis3DLayout, object):
         else:
             return False
 
-        # export the image
-
     @aedt_exception_handler
     def export_touchstone(self, solutionname, sweepname, filename, variation, variations_value):
-        """Export the touchstone file
+        """Export a Touchstone file.
         
-        
-        solutionname = name of the solution solved
-        sweepname = name of the sweep solved
-        FileName = full path of output file
-        Variations = list (list of all parameters variations e.g. ["$AmbientTemp", "$PowerIn"] )
-        VariationsValue = list (list of all parameters variations value) e.g. ["22cel", "100"] )
-
         Parameters
         ----------
-        solutionname :
-            
-        sweepname :
-            
-        filename :
-            
-        variation :
-            
-        variations_value :
-            
+        solutionname : str
+            Name of the solution that has been solved.    
+        sweepname : str
+            Name of the sweep that has been solved.
+        filename : str
+            Full path for the Touchstone file.
+        variation : list
+            List of all parameter variations, such  as ``["$AmbientTemp", "$PowerIn"]``.
+        variations_value : list
+            List of all parameter variation values, such as ``["22cel", "100"]``.
 
         Returns
         -------
-
+        bool
+            ``True`` when successful, ``False`` when failed.
+        
         """
-
         # normalize the save path
         if not filename:
             appendix = ""
@@ -509,33 +536,34 @@ class Hfss3dLayout(FieldAnalysis3DLayout, object):
         return True
 
     @aedt_exception_handler
-    def set_export_touchstone(self, activate):
-        """Set Automatic export of touchstone after simulation to True
+    def set_export_touchstone(self, activate, export_dir=""):
+        """Export the Touchstone file automatically if the simulation is successful.
 
         Parameters
         ----------
         activate : bool
-            Export after simulation
+            Whether to export after the simulation.
+        eport_dir str, optional
+            Path to export the file to. The defaultis ``""``.
 
         Returns
         -------
-        type
-            True if operation succeeded
-
+        bool
+            ``True`` when successful, ``False`` when failed.
+        
         """
-
         settings = []
         if activate:
-            settings.append("NAME:Design Settings Data")
-            settings.append("Export After Simulation:=")
+            settings.append("NAME:options")
+            settings.append("ExportAfterSolve:=")
             settings.append(True)
-            settings.append("Export Dir:=")
-            settings.append("")
+            settings.append("ExportDir:=")
+            settings.append(export_dir)
         elif not activate:
-            settings.append("NAME:Design Settings Data")
-            settings.append("Export After Simulation:=")
+            settings.append("NAME:options")
+            settings.append("ExportAfterSolve:=")
             settings.append(False)
-        self.odesign.SetDesignSettings(settings)
+        self.odesign.DesignOptions(settings, 0)
         return True
 
     @aedt_exception_handler
@@ -544,48 +572,49 @@ class Hfss3dLayout(FieldAnalysis3DLayout, object):
                                interpolation_tol_percent=0.5, interpolation_max_solutions=250,
                                save_fields=True, save_rad_fields_only=False,
                                use_q3d_for_dc=False):
-        """Create a Frequency Sweep
+        """Create a frequency sweep.
 
         Parameters
         ----------
-        setupname :
-            name of the setup to which is attached the sweep
-        unit :
-            Units ("MHz", "GHz"....)
-        freqstart :
-            Starting Frequency of sweep
-        freqstop :
-            Stop Frequency of Sweep
-        sweepname :
-            name of the Sweep (Default value = None)
-        num_of_freq_points :
-            Number of frequency point in the range
-        sweeptype :
-            discrete"|"interpolating" (default)
-        interpolation_max_solutions :
-            max number of solutions evaluated for the interpolation process (Default value = 250)
-        interpolation_tol_percent :
-            error tolerance threshold for the interpolation process (Default value = 0.5)
-        save_fields :
-            save the fields (only for discrete sweep) (Default value = True)
-        save_rad_fields_only :
-            save only the radiated fields (only if save_fields = True) (Default value = False)
-        use_q3d_for_dc :
-            Use Q3D to solve DC point (Default value = False)
+        setupname : str
+            Name of the setup to attach to the sweep.
+        unit : str
+            Unit of the frequency, such as ``"MHz"`` or ``"GHz"``.
+        freqstart : float
+            Starting frequency of the sweep.
+        freqstop : float
+            Stopping frequency of the sweep.
+        num_of_freq_points : int
+            Number of frequency points in the range.
+        sweepname : str, optional
+            Name of the sweep. The default is ``None``.
+        sweeptype : str, optional
+            Type of the sweep. Options are ``"Fast"``, ``"Interpolating"``, and ``"Discrete"``. 
+            The default is ``"Interpolating"``.
+        interpolation_tol_percent : float, optional
+            Error tolerance threshold for the interpolation process. The default is ``0.5``.
+        interpolation_max_solutions : int, optional
+            Maximum number of solutions evaluated for the interpolation process. The default is ``250``.
+        save_fields : bool, optional
+            Whether to save the fields for a discrete sweep only. The default is ``True``.
+        save_rad_fields_only : bool, optional
+            Whether to save only the radiated fields if ``save_fields=True``. The default is ``False``.
+        use_q3d_for_dc : bool, optional
+            Whether to use Q3D to solve the DC point. The default is ``False``.
 
         Returns
         -------
-        type
-            Setup Name if operation succeeded
-
+        str
+            Name of the setup when successful, ``False`` otherwise.
+        
         """
         if sweepname is None:
             sweepname = generate_unique_name("Sweep")
+        interpolation = False
         if sweeptype == "interpolating":
             interpolation = True
             save_fields = False
-        elif sweeptype == "discrete":
-            interpolation = False
+
         if not save_fields:
             save_rad_fields_only = False
         interpolation_tol = interpolation_tol_percent / 100.
@@ -596,48 +625,101 @@ class Hfss3dLayout(FieldAnalysis3DLayout, object):
         #   sweep.add_sweep([1, 1000, 100], "log_scale", "kHz")
         #   sweep.add_sweep([7,13,17,19,23], "single", unit)
         sweep_string = sweep.get_string()
-
-        arg = ["NAME:" + sweepname,
-               [
-                "NAME:Properties",
-                "Enable:=", "true"
-               ],
-               [
-                "NAME:Sweeps",
-                "Variable:=", sweepname,
-                "Data:=", sweep_string,
-                "OffsetF1:=", False,
-                "Synchronize:=", 0
-               ],
-               "GenerateSurfaceCurrent:=", save_fields,
-               "SaveRadFieldsOnly:=", save_rad_fields_only,
-               "FastSweep:=", interpolation,
-               "ZoSelected:=", False,
-               "SAbsError:=", interpolation_tol,
-               "ZoPercentError:=", 1,
-               "GenerateStateSpace:=", False,
-               "EnforcePassivity:=", interpolation,
-               "PassivityTolerance:=", 0.0001,
-               "UseQ3DForDC:=", use_q3d_for_dc,
-               "ResimulateDC:=", False,
-               "MaxSolutions:=", interpolation_max_solutions,
-               "InterpUseSMatrix:=", True,
-               "InterpUsePortImpedance:=", True,
-               "InterpUsePropConst:=", True,
-               "InterpUseFullBasis:=", True,
-               "CustomFrequencyString:=", "",
-               "AllEntries:=", False,
-               "AllDiagEntries:=", False,
-               "AllOffDiagEntries:=", False,
-               "MagMinThreshold:=", 0.01
-               ]
-
-        self.oanalysis.AddSweep(setupname, arg)
+        setup = self.get_setup(setupname)
+        if sweepname in [name.name for name in setup.sweeps]:
+            sweepname = generate_unique_name(sweepname)
+        sweep= setup.add_sweep(sweepname=sweepname)
+        sweep.change_range("LinearCount", freqstart,freqstop, num_of_freq_points )
+        setup.props["GenerateSurfaceCurrent"]=save_fields
+        setup.props["SaveRadFieldsOnly"] = save_rad_fields_only
+        setup.props["FastSweep"] = interpolation
+        setup.props["SAbsError"] = interpolation_tol
+        setup.props["EnforcePassivity"] = interpolation
+        setup.props["UseQ3DForDC"] = use_q3d_for_dc
+        setup.props["MaxSolutions"] = interpolation_max_solutions
+        setup.update()
+        # arg = ["NAME:" + sweepname,
+        #        [
+        #         "NAME:Properties",
+        #         "Enable:=", "true"
+        #        ],
+        #        [
+        #         "NAME:Sweeps",
+        #         "Variable:=", sweepname,
+        #         "Data:=", sweep_string,
+        #         "OffsetF1:=", False,
+        #         "Synchronize:=", 0
+        #        ],
+        #        "GenerateSurfaceCurrent:=", save_fields,
+        #        "SaveRadFieldsOnly:=", save_rad_fields_only,
+        #        "FastSweep:=", interpolation,
+        #        "ZoSelected:=", False,
+        #        "SAbsError:=", interpolation_tol,
+        #        "ZoPercentError:=", 1,
+        #        "GenerateStateSpace:=", False,
+        #        "EnforcePassivity:=", interpolation,
+        #        "PassivityTolerance:=", 0.0001,
+        #        "UseQ3DForDC:=", use_q3d_for_dc,
+        #        "ResimulateDC:=", False,
+        #        "MaxSolutions:=", interpolation_max_solutions,
+        #        "InterpUseSMatrix:=", True,
+        #        "InterpUsePortImpedance:=", True,
+        #        "InterpUsePropConst:=", True,
+        #        "InterpUseFullBasis:=", True,
+        #        "CustomFrequencyString:=", "",
+        #        "AllEntries:=", False,
+        #        "AllDiagEntries:=", False,
+        #        "AllOffDiagEntries:=", False,
+        #        "MagMinThreshold:=", 0.01
+        #        ]
+        #
+        # self.oanalysis.AddSweep(setupname, arg)
         # self.oanalysis_setup.AddSweep(setupname, arg)
         # self._messenger.add_debug_message("Sweep Setup created correctly")
-        return sweepname
-
-
+        return setup
 
+    @aedt_exception_handler
+    def import_gds(self, gds_path, aedb_path=None, xml_path=None, set_as_active=True, close_active_project=False):
+        """Import grounds into the HFSS 3D Layout and assign the stackup from an XML file if present.
 
+        Parameters
+        ----------
+        gds_path : str
+            Full path to the GDS file.
+        aedb_path : str, optional
+            Full path to the AEDB file.
+        xml_path : str, optional
+            Path to the XML file with the stackup information. The default is ``None``, in 
+            which case the stackup is not edited.
+        set_as_active : bool, optional
+            Whether to set the GDS file as active. The default is ``True``.
+        close_active_project : bool, optional
+            Whether to close the active project after loading the GDS file.
+            The default is ''False``.
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+        
+        """
+        active_project = self.project_name
+        project_name = os.path.basename(gds_path)[:-4]
+        if not aedb_path:
+            aedb_path = gds_path.replace('.gds', '.aedb')
+        if os.path.exists(aedb_path):
+            old_name = project_name
+            project_name = generate_unique_name(project_name)
+            aedb_path = gds_path.replace(old_name + '.gds', project_name + '.aedb')
+            self._messenger.add_warning_message("aedb_exists. Renaming it to {}".format(project_name))
 
+        oTool = self.odesktop.GetTool("ImportExport")
+        oTool.ImportGDSII(gds_path, aedb_path, "", "")
+        project = self.odesktop.SetActiveProject(project_name)
+        oeditor = project.GetActiveDesign().SetActiveEditor("Layout")
+        if xml_path:
+            oeditor.ImportStackupXML(xml_path)
+        if set_as_active:
+            self.__init__(project_name)
+        if close_active_project:
+            self.odesktop.CloseProject(active_project)
+        return True
