@@ -1,22 +1,39 @@
-from ..generic.general_methods import aedt_exception_handler
+from ..generic.general_methods import aedt_exception_handler, retry_ntimes
 from .PrimitivesCircuit import CircuitComponents
 
 
 class NexximComponents(CircuitComponents):
-    """Class for management of all CircuitComponents for Nexxim"""
+    """Manages circuit components for Nexxim.
+    
+    Parameters
+    ----------
+    parent :
+        Inherited parent object.
+    modeler :
+    
+    """
     @property
     def design_libray(self):
+        """Design library."""
         return "Nexxim Circuit Elements"
 
     @property
     def tab_name(self):
+        """Tab name."""
         return "PassedParameterTab"
 
     @aedt_exception_handler
     def __getitem__(self, partname):
-        """
-        :param partname: if integer try to get the object id. if string, trying to get object Name
-        :return: part object details
+        """Get the object ID if the part name is an integer or the object name if it is a string.
+        Parameters
+        ----------
+        partname: int or str
+            Part ID or object name. 
+        
+        Returns
+        -------
+        type
+            Part object details.
         """
         if type(partname) is int:
             return self.components[partname]
@@ -35,12 +52,12 @@ class NexximComponents(CircuitComponents):
 
     @aedt_exception_handler
     def create_3dlayout_subcircuit(self, sourcename):
-        """Create a new subcircuit
+        """Create a subcircuit.
 
         Parameters
         ----------
-        sourcename :
-            name of the source design
+        sourcename : str
+            Name of the source design.
 
         Returns
         -------
@@ -58,26 +75,28 @@ class NexximComponents(CircuitComponents):
 
     @aedt_exception_handler
     def create_field_model(self, design_name, solution_name, pin_names, model_type="hfss", posx=0, posy=1):
-        """Create Field Model
+        """Create a field model.
 
         Parameters
         ----------
-        design_name :
-            param solution_name:
-        pin_names :
-            param model_type:
-        posx :
-            param posy: (Default value = 0)
-        solution_name :
-            
-        model_type :
-             (Default value = "hfss")
-        posy :
-             (Default value = 1)
+        design_name : str
+            Name of the design.
+        solution_name: str
+            Name  of the solution.
+        pin_names : list
+            List of the pin names.
+        model_type: str, optional
+            Type of the model. The default is ``"hfss"``.
+        posx : float, optional
+            Position on the X axis. The default is ``0``.    
+        posy : float, optional.
+            Position on the Y axis. The default is ``1``.
 
         Returns
         -------
-
+        bool
+            ``True`` when successful, ``False`` when failed.
+        
         """
         id = self.create_unique_id()
         component_name = design_name + "_" + str(id)
@@ -187,28 +206,31 @@ class NexximComponents(CircuitComponents):
 
     @aedt_exception_handler
     def create_resistor(self, compname=None, value=50, xpos=0, ypos=0,angle=0, use_instance_id_netlist=False):
-        """Create a new Resistor
+        """Create a resistor.
 
         Parameters
         ----------
-        compname :
-            name (Default value = None)
-        value :
-            value (Default value = 50)
-        xpos :
-            x pos (Default value = 0)
-        ypos :
-            y pos (Default value = 0)
-        angle :
-            angle (Default value = 0)
-        use_instance_id_netlist :
-            bool (Default value = False)
+        compname : str, optional
+            Name of the resistor. The default is ``None``.
+        value : float, optional
+            Resistance in ohms. The default is ``50``.
+        xpos : float, optional
+            Position on the X axis. The default is ``0``.    
+        ypos: float, optional
+            Position on the Y axis. The default is ``0``.
+        angle : float, optional
+            Angle rotation in degrees. The default is ``0``.
+        use_instance_id_netlist : bool, optional
+            Whether to use the instance ID in the net list. 
+            The default is ``False``.
 
         Returns
         -------
-        type
-            id, name
-
+        int
+            ID of the resistor.
+        str
+            Name of the resistor.
+        
         """
         cmpid, cmpname = self.create_component(compname, xpos=xpos, ypos=ypos, angle=angle, use_instance_id_netlist=use_instance_id_netlist)
 
@@ -217,28 +239,31 @@ class NexximComponents(CircuitComponents):
 
     @aedt_exception_handler
     def create_inductor(self, compname=None,value=50, xpos=0, ypos=0,angle=0, use_instance_id_netlist=False):
-        """Create a new Inductor
+        """Create an inductor.
 
         Parameters
         ----------
-        compname :
-            name (Default value = None)
-        value :
-            value (Default value = 50)
-        xpos :
-            x pos (Default value = 0)
-        ypos :
-            y pos (Default value = 0)
-        angle :
-            angle (Default value = 0)
-        use_instance_id_netlist :
-            bool (Default value = False)
+        compname : str, optional
+            Name of the inductor. The default is ``None``.
+        value : float, optional
+            Inductance value. The default is ``50``.
+        xpos : float, optional
+            Position on the X axis. The default is ``0``.    
+        ypos: float, optional
+            Position on the X axis. The default is ``0``.    
+        angle : float, optional
+            Angle rotation in degrees. The default is ``0``.
+        use_instance_id_netlist : bool, optional
+            Whether to use the instance ID in the net list. 
+            The default is ``False``.
 
         Returns
         -------
-        type
-            id, name
-
+        int
+            ID of the inductor.
+        str
+            Name of the inductor.
+        
         """
         cmpid, cmpname = self.create_component(compname, component_library="Inductors", component_name="IND_", xpos=xpos, ypos=ypos,
                                          angle=angle, use_instance_id_netlist=use_instance_id_netlist)
@@ -249,28 +274,31 @@ class NexximComponents(CircuitComponents):
 
     @aedt_exception_handler
     def create_capacitor(self, compname=None,value=50, xpos=0, ypos=0, angle=0, use_instance_id_netlist=False):
-        """Create a new Capacitor
+        """Create a capacitor.
 
         Parameters
         ----------
-        compname :
-            name (Default value = None)
-        value :
-            value (Default value = 50)
-        xpos :
-            x pos (Default value = 0)
-        ypos :
-            y pos (Default value = 0)
-        angle :
-            angle (Default value = 0)
-        use_instance_id_netlist :
-            bool (Default value = False)
-
+        compname : str, optional
+            Name of the capacitor. The default is ``None``.
+        value : float, optional
+            Capacitor value. The default is ``50``.
+        xpos : float, optional
+            Position on the X axis. The default is ``0``.    
+        ypos: float, optional
+            Position on the Y axis. The default is ``0``.
+        angle : float, optional
+            Angle rotation in degrees. The default is ``0``.
+        use_instance_id_netlist : bool, optional
+            Whether to use the instance ID in the net list. 
+            The default is ``False``.
+        
         Returns
         -------
-        type
-            id, name
-
+        int
+            ID of the capacitor.
+        str
+            Name of the capacitor.
+        
         """
         cmpid, cmpname = self.create_component(compname,component_library="Capacitors", component_name="CAP_", xpos=xpos, ypos=ypos,
                                          angle=angle, use_instance_id_netlist=use_instance_id_netlist)
@@ -280,28 +308,30 @@ class NexximComponents(CircuitComponents):
 
     @aedt_exception_handler
     def create_voltage_dc(self, compname=None, value=1, xpos=0, ypos=0, angle=0, use_instance_id_netlist=False):
-        """Create a new Voltage DC Source
+        """Create a voltage DC source.
 
         Parameters
         ----------
-        compname :
-            name (Default value = None)
-        value :
-            value (Default value = 1)
-        xpos :
-            x pos (Default value = 0)
-        ypos :
-            y pos (Default value = 0)
-        angle :
-            angle (Default value = 0)
-        use_instance_id_netlist :
-            bool (Default value = False)
+        compname : str, optional
+            Name of the voltage DC source. The default is ``None``.
+        value : float, optional
+            Voltage value. The default is ``50``.
+        xpos : float, optional
+            Position on the X axis. The default is ``0``.    
+        ypos: float, optional
+        angle : float, optional
+            Angle rotation in degrees. The default is ``0``.
+        use_instance_id_netlist : bool, optional
+            Whether to use the instance ID in the net list. 
+            The default is ``False``.
 
         Returns
         -------
-        type
-            id, name
-
+        int
+            ID of the voltage DC source.
+        str
+            Name of the voltage DC source.
+        
         """
         cmpid, cmpname = self.create_component(compname,component_library="Independent Sources", component_name="V_DC", xpos=xpos, ypos=ypos,
                                          angle=angle, use_instance_id_netlist=use_instance_id_netlist)
@@ -311,30 +341,31 @@ class NexximComponents(CircuitComponents):
 
     @aedt_exception_handler
     def create_current_pulse(self, compname=None, value_lists=[], xpos=0, ypos=0, angle=0, use_instance_id_netlist=False):
-        """Create a new Current Pulse
+        """Create a current pulse.
 
         Parameters
         ----------
-        compname :
-            name (Default value = None)
-        value :
-            value
-        xpos :
-            x pos (Default value = 0)
-        ypos :
-            y pos (Default value = 0)
-        angle :
-            angle (Default value = 0)
-        use_instance_id_netlist :
-            bool (Default value = False)
-        value_lists :
-             (Default value = [])
-
+        compname : str, optional
+            Name of the current pulse. The default is ``None``.
+        value_lists : list, optional
+            List of values for the current pulse. The default is ``[]``.
+        xpos : float, optional
+            Position on the X axis. The default is ``0``.    
+        ypos: float, optional
+            Position on the Y axis. The default is ``0``.
+        angle : float, optional
+            Angle rotation in degrees. The default is ``0``.
+        use_instance_id_netlist : bool, optional
+            Whether to use the instance ID in the net list. 
+            The default is ``False``.
+        
         Returns
         -------
-        type
-            id, name
-
+        int
+            ID of the current pulse.
+        str
+            Name of the current pulse.
+        
         """
         cmpid, cmpname = self.create_component(compname,component_library="Independent Sources", component_name="I_PULSE", xpos=xpos, ypos=ypos,
                                          angle=angle, use_instance_id_netlist=use_instance_id_netlist)
@@ -359,30 +390,31 @@ class NexximComponents(CircuitComponents):
 
     @aedt_exception_handler
     def create_voltage_pulse(self, compname=None, value_lists=[], xpos=0, ypos=0, angle=0, use_instance_id_netlist=False):
-        """Create a new Voltage Pulse
+        """Create a voltage pulse.
 
         Parameters
         ----------
-        compname :
-            name (Default value = None)
-        value :
-            value
-        xpos :
-            x pos (Default value = 0)
-        ypos :
-            y pos (Default value = 0)
-        angle :
-            angle (Default value = 0)
-        use_instance_id_netlist :
-            bool (Default value = False)
-        value_lists :
-             (Default value = [])
-
+        compname : str, optional
+            Name of the voltage pulse. The default is ``None``.
+        value_lists : list, optional
+            List of values for the voltage pulse. The default is ``[]``.
+        xpos : float, optional
+            Position on the X axis. The default is ``0``.    
+        ypos: float, optional
+            Position on the Y axis. The default is ``0``.
+        angle : float, optional
+            Angle rotation in degrees. The default is ``0``.
+        use_instance_id_netlist : bool, optional
+            Whether to use the instance ID in the net list. 
+            The default is ``False``.
+        
         Returns
         -------
-        type
-            id, name
-
+        int
+            ID of the voltage pulse.
+        str
+            Name of the voltage pulse.
+        
         """
         cmpid, cmpname = self.create_component(compname,component_library="Independent Sources", component_name="V_PULSE", xpos=xpos, ypos=ypos,
                                          angle=angle, use_instance_id_netlist=use_instance_id_netlist)
@@ -408,28 +440,31 @@ class NexximComponents(CircuitComponents):
 
     @aedt_exception_handler
     def create_current_dc(self, compname=None, value=1, xpos=0, ypos=0, angle=0, use_instance_id_netlist=False):
-        """Create a new Current DC Source
+        """Create a current DC source.
 
         Parameters
         ----------
-        compname :
-            name (Default value = None)
-        value :
-            value (Default value = 1)
-        xpos :
-            x pos (Default value = 0)
-        ypos :
-            y pos (Default value = 0)
-        angle :
-            angle (Default value = 0)
-        use_instance_id_netlist :
-            bool (Default value = False)
+        compname : str, optional
+            Name of the current DC source. The default is ``None``.
+        value : float, optional
+            Current value. The default is ``1``.
+        xpos : float, optional
+            Position on the X axis. The default is ``0``.    
+        ypos: float, optional
+            Position on the Y axis. The default is ``0``.
+        angle : float, optional
+            Angle rotation in degrees. The default is ``0``.
+        use_instance_id_netlist : bool, optional
+            Whether to use the instance ID in the net list. 
+            The default is ``False``.
 
         Returns
         -------
-        type
-            id, name
-
+        int
+            ID of the current DC source.
+        str
+            Name of the current DC source.
+        
         """
         cmpid, cmpname = self.create_component(compname,component_library="Independent Sources", component_name="I_DC", xpos=xpos, ypos=ypos,
                                          angle=angle, use_instance_id_netlist=use_instance_id_netlist)
@@ -438,32 +473,35 @@ class NexximComponents(CircuitComponents):
         return cmpid, cmpname
 
     def create_coupling_inductors(self, compname, l1, l2, value=1, xpos=0, ypos=0, angle=0, use_instance_id_netlist=False):
-        """Create a new Coupling Inductor
+        """Create a coupling inductor.
 
         Parameters
         ----------
-        compname :
-            name
-        value :
-            value (Default value = 1)
-        xpos :
-            x pos (Default value = 0)
-        ypos :
-            y pos (Default value = 0)
-        angle :
-            angle (Default value = 0)
-        use_instance_id_netlist :
-            bool (Default value = False)
-        l1 :
-            
-        l2 :
-            
+        compname : str
+            Name of the coupling inductor.
+        l1 : float, optional
+            Value for the first inductor.
+        l2 : float, optional
+            Value for the second inductor.
+        value : float, optional
+            Value for the coupling inductor. The default is ``1``.
+        xpos : float, optional
+            Position on the X axis. The default is ``0``.    
+        ypos: float, optional
+            Position on the Y axis. The default is ``0``.
+        angle : float, optional
+            Angle rotation in degrees. The default is ``0``.
+        use_instance_id_netlist : bool, optional
+            Whether to use the instance ID in the net list. 
+            The default is ``False``.   
 
         Returns
         -------
-        type
-            id, name
-
+        int
+            ID of the coupling inductor.
+        str
+            Name of the coupling inductor.
+        
         """
         cmpid, cmpname = self.create_component(compname,component_library="Inductors", component_name="K_IND", xpos=xpos, ypos=ypos,
                                          angle=angle, use_instance_id_netlist=use_instance_id_netlist)
@@ -475,30 +513,31 @@ class NexximComponents(CircuitComponents):
 
     @aedt_exception_handler
     def create_diode(self, compname=None,model_name="required", xpos=0, ypos=0, angle=0, use_instance_id_netlist=False):
-        """Create a new Diode
+        """Create a diode.
 
         Parameters
         ----------
-        compname :
-            name (Default value = None)
-        value :
-            value
-        xpos :
-            x pos (Default value = 0)
-        ypos :
-            y pos (Default value = 0)
-        angle :
-            angle (Default value = 0)
-        use_instance_id_netlist :
-            bool (Default value = False)
-        model_name :
-             (Default value = "required")
-
+        compname : str
+            Name of the diode. The default is ``None``.
+        model_name : str, optional
+            Name of the model. The default is ``"required"``.
+        xpos : float, optional
+            Position on the X axis. The default is ``0``.    
+        ypos: float, optional
+            Position on the Y axis. The default is ``0``.
+        angle : float, optional
+            Angle rotation in degrees. The default is ``0``.
+        use_instance_id_netlist : bool, optional
+            Whether to use the instance ID in the net list. 
+            The default is ``False``.
+       
         Returns
         -------
-        type
-            id, name
-
+        int
+            ID of the diode.
+        str
+            Name of the diode.
+        
         """
         cmpid, cmpname = self.create_component(compname,component_library="Diodes", component_name="DIODE_Level1", xpos=xpos, ypos=ypos,
                                          angle=angle, use_instance_id_netlist=use_instance_id_netlist)
@@ -508,30 +547,32 @@ class NexximComponents(CircuitComponents):
 
     @aedt_exception_handler
     def create_npn(self, compname=None, value=None, xpos=0, ypos=0, angle=0, use_instance_id_netlist=False):
-        """Create a new Transistor NPN
+        """Create an NPN transistor.
 
         Parameters
         ----------
-        compname :
-            name (Default value = None)
-        value :
-            value (Default value = None)
-        xpos :
-            x pos (Default value = 0)
-        ypos :
-            y pos (Default value = 0)
-        angle :
-            angle (Default value = 0)
-        use_instance_id_netlist :
-            bool (Default value = False)
-
+        compname : str
+            Name of the NPN transistor. The default is ``None``.
+        value : float, optional
+            Value for the NPN transistor. The default is ``None``.
+        xpos : float, optional
+            Position on the X axis. The default is ``0``.    
+        ypos: float, optional
+            Position on the Y axis. The default is ``0``.
+        angle : float, optional
+            Angle rotation in degrees. The default is ``0``.
+        use_instance_id_netlist : bool, optional
+            Whether to use the instance ID in the net list. 
+            The default is ``False``.
+        
         Returns
         -------
-        type
-            id, name
-
+        int
+            ID of the NPN transistor.
+        str
+            Name of the NPN transistor.
+        
         """
-
         id, name = self.create_component(compname,component_library="BJTs", component_name="Level01_NPN", xpos=xpos, ypos=ypos,
                                          angle=angle, use_instance_id_netlist=use_instance_id_netlist)
         if value:
@@ -540,28 +581,31 @@ class NexximComponents(CircuitComponents):
 
     @aedt_exception_handler
     def create_pnp(self, compname=None,value=50, xpos=0, ypos=0, angle=0, use_instance_id_netlist=False):
-        """Create a new Transistor PNP
+        """Create a PNP transistor.
 
         Parameters
         ----------
-        compname :
-            name (Default value = None)
-        value :
-            value (Default value = 50)
-        xpos :
-            x pos (Default value = 0)
-        ypos :
-            y pos (Default value = 0)
-        angle :
-            angle (Default value = 0)
-        use_instance_id_netlist :
-            bool (Default value = False)
-
+        compname : str
+            Name of the PNP transistor. The default is ``None``.
+        value : float, optional
+            Value for the PNP transistor. The default is ``None``.
+        xpos : float, optional
+            Position on the X axis. The default is ``0``.    
+        ypos: float, optional
+            Position on the Y axis. The default is ``0``.
+        angle : float, optional
+            Angle rotation in degrees. The default is ``0``.
+        use_instance_id_netlist : bool, optional
+            Whether to use the instance ID in the net list. 
+            The default is ``False``.
+        
         Returns
         -------
-        type
-            id, name
-
+        int
+            ID of the PNP transistor.
+        str
+            Name of the PNP transistor.
+        
         """
         id, name = self.create_component(compname, component_library="BJTs", component_name="Level01_PNP", xpos=xpos, ypos=ypos,
                                          angle=angle, use_instance_id_netlist=use_instance_id_netlist)
@@ -572,26 +616,26 @@ class NexximComponents(CircuitComponents):
 
     @aedt_exception_handler
     def create_new_component_from_symbol(self,symbol_name, pin_lists, Refbase = "U", parameter_list=[], parameter_value=[]):
-        """Create a new Component from symbol
+        """Create a component from a symbol.
 
         Parameters
         ----------
-        symbol_name :
-            symbol name
-        pin_lists :
-            list of pins name
-        Refbase :
-            reference base (Default value = "U")
-        parameter_list :
-            list of parameters (Default value = [])
-        parameter_value :
-            list of parameters values (Default value = [])
+        symbol_name : str
+            Name of the symbol.
+        pin_lists : list
+            List of pin names.
+        Refbase : str, optional
+            Reference base. The default is ``"U"``.
+        parameter_list : list
+            List of parameters. The default is ``[]``.
+        parameter_value : list
+            List of parameter values. The default is ``[]``.
 
         Returns
         -------
-        type
-            true
-
+        bool
+            ``True`` when successful, ``False`` when failed.
+        
         """
         arg = ["NAME:" + symbol_name, "Info:=",
                ["Type:=", 0, "NumTerminals:=", len(pin_lists), "DataSource:=", "", "ModifiedOn:=", 1591858313, "Manufacturer:=", "",
@@ -650,54 +694,56 @@ class NexximComponents(CircuitComponents):
 
     @aedt_exception_handler
     def update_object_properties(self, o):
-        """
+        """Update the properties of an object.
 
         Parameters
         ----------
         o :
-            object
+            Object to update.
 
         Returns
         -------
-        type
-            object with properties
-
+        :class:`pyaedt.modeler.Object3d.CircuitComponent`
+            Object with properties.
+        
         """
         name = o.composed_name
         proparray = self.oeditor.GetProperties("PassedParameterTab", name)
         for j in proparray:
-            propval = self.oeditor.GetPropertyValue("PassedParameterTab", name, j)
+            propval = retry_ntimes(10, self.oeditor.GetPropertyValue,"PassedParameterTab", name, j)
             o._add_property(j, propval)
         return o
 
     @aedt_exception_handler
     def get_comp_custom_settings(self, toolNum ,dc = 0, interp=0, extrap=1, conv=0, passivity=0, reciprocal="False", opt="", data_type=1):
-        """
+        """Retrieve custom settings for a resistor.
 
         Parameters
         ----------
         toolNum :
-            param dc:
-        interp :
-            param extrap: (Default value = 0)
-        conv :
-            param passivity: (Default value = 0)
-        reciprocal :
-            param opt: (Default value = "False")
-        data_type :
-            return: (Default value = 1)
+        
         dc :
-             (Default value = 0)
-        extrap :
-             (Default value = 1)
-        passivity :
-             (Default value = 0)
-        opt :
-             (Default value = "")
+            The default is ``0``.
+        interp :
+            The default is ``0``.
+        extrap : 
+            The default is ``1``.
+        conv :
+            The default is ``0``.
+        passivity : optional
+            The default is ``0``.
+        reciprocal : bool, optional
+            The default is ``False``.
+        opt : str, optional
+            The default is ``""``.
+        data_type : optional
+            Type of the data. The default is ``1``.  
 
         Returns
         -------
-
+        list
+            List of the custom settings for the resistor.
+        
         """
         if toolNum == 1:
             custom = "NAME:DesignerCustomization"
@@ -720,26 +766,29 @@ class NexximComponents(CircuitComponents):
 
     @aedt_exception_handler
     def add_subcircuit_hfss_link(self, compName, pin_names, source_project_path, source_project_name, source_design_name, solution_name = "Setup1 : Sweep"):
-        """
+        """Add a subcircuit HFSS link.
 
         Parameters
         ----------
-        compName :
-            param pin_names:
-        source_project_path :
-            param source_project_name:
-        source_design_name :
-            param solution_name:
-        pin_names :
-            
-        source_project_name :
-            
-        solution_name :
-             (Default value = "Setup1 : Sweep")
-
+        compName : str
+            Name of the subcircuit HFSS link.
+        pin_names: list
+            List of the pin names.
+        source_project_path : str
+            Path to the source project.      
+        source_project_name: str
+            Name  of the source project.
+        source_design_name : str
+            Name of the design.
+        solution_name: str, optional
+            Name of the solution and sweep. The 
+            default is ``"Setup1 : Sweep"``.
+        
         Returns
         -------
-
+        bool
+            ``True`` when successful, ``False`` when failed.
+        
         """
         designer_customization = self.get_comp_custom_settings(1, 0, 0, 1, 0, 0, "False", "", 1)
         nexxim_customization = self.get_comp_custom_settings(2, 3, 1, 3, 0, 0, "False", "", 2)
@@ -831,16 +880,18 @@ class NexximComponents(CircuitComponents):
 
     @aedt_exception_handler
     def set_sim_option_on_hfss_subcircuit(self, component):
-        """
+        """Set the simulation option on the HFSS subscircuit.
 
         Parameters
         ----------
-        component :
-            CompInst@Galileo_cutout3;87;1
+        component : str
+            Address of the component instance. For example, ``"Inst@Galileo_cutout3;87;1"``.
 
         Returns
         -------
-
+        bool
+            ``True`` when successful, ``False`` when failed.
+        
         """
         complist = component.split(";")
         complist2 = complist[0].split("@")
@@ -862,76 +913,114 @@ class NexximComponents(CircuitComponents):
         pass
 
     @aedt_exception_handler
-    def refresh_dynamic_link(self, component_name):
-        """
+    def set_sim_solution_on_hfss_subcircuit(self, component, solution_name="Setup1 : Sweep"):
+        """Set the simulation solution on the HFSS subcircuit.
 
         Parameters
         ----------
-        component_name :
+        component : str
+            Address of the component instance. For example, ``"Inst@Galileo_cutout3;87;1"``.
+        solution_name: str, optional
+            Name of the solution and sweep. The default is ``"Setup1 : Sweep"``.
+
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+        
+        """
+        complist = component.split(";")
+        complist2 = complist[0].split("@")
+        arg = ["NAME:AllTabs"]
+        arg1 = ["NAME:Model"]
+        arg2 = ["NAME:PropServers", "Component@" + str(complist2[1])]
+        arg3 = ["NAME:ChangedProps", ["NAME:Solution", "Value:=", solution_name]]
+
+        arg1.append(arg2)
+        arg1.append(arg3)
+        arg.append(arg1)
+
+        self._parent._oproject.ChangeProperty(arg)
+
+        argo = ["NAME:AllTabs", ["NAME:Component", ["NAME:PropServers", str(component)]]]
+
+        self.oeditor.ChangeProperty(argo)
+
+        return True
+
+    @aedt_exception_handler
+    def refresh_dynamic_link(self, component_name):
+        """Refresh a dynamic link.
+
+        Parameters
+        ----------
+        component_name : str
+            Name of the dynamic link.
             
 
         Returns
         -------
-
+        bool
+            ``True`` when successful, ``False`` when failed.
+        
         """
         self.o_component_manager.UpdateDynamicLink(component_name)
 
     @aedt_exception_handler
-    def push_excitations(self, instance_name,thevenin_calculation = False):
-        """
+    def push_excitations(self, instance_name, thevenin_calculation=False, setup_name="LinearFrequency"):
+        """Push excitations.
 
         Parameters
         ----------
-        instance_name :
-            
-        thevenin_calculation :
-             (Default value = False)
+        instance_name : str
+            Name of the instance.
+        thevenin_calculation : bool, optional
+            Whether to perform the Thevenin equivalent calculation. The default is ``False``.
+        setup_name : str
+            Name of the solution setup to push.
 
         Returns
         -------
-
+        bool
+            ``True`` when successful, ``False`` when failed.
+        
         """
         arg = ["NAME:options",
                "CalcThevenin:=", thevenin_calculation,
-               "Sol:=", "LinearFrequency"]
+               "Sol:=", setup_name]
 
-        self.oeditor.PushExcitation(instance_name, arg)
+        self.oeditor.PushExcitations(instance_name, arg)
         pass
 
     @aedt_exception_handler
     def assign_sin_excitation2ports(self, ports, settings):
-        """
+        """Assign a sinusoidal excitation to circuit ports.
 
         Parameters
         ----------
-        ports :
-            List of circuit ports for excitation assignation
-        settings :
-            List of parameters values used in voltage sinusoidal excitation creation:
-        settings :
-            0]: AC magnitude for small-signal analysis
-        settings :
-            1]: AC phase for small-signal analysis
-        settings :
-            2]: DC voltage
-        settings :
-            3]: Voltage offset from zero
-        settings :
-            4]: Voltage amplitude
-        settings :
-            5]: Frequency
-        settings :
-            6]: Delay to start of sine wave
-        settings :
-            7]: Damping factor
-        settings :
-            8]: Phase Delay
-        settings :
-            9]: Frequency to use for harmonic balance analysis
+        ports : list
+            List of circuit ports to assign to the sinusoidal excitation.
+        settings : list
+            List of parameter values to use in voltage sinusoidal excitation creation.
+            
+            Values are given in this order:
+        
+            * 0: AC magnitude for small-signal analysis
+            * 1: AC phase for small-signal analysis
+            * 2: DC voltage
+            * 3: Voltage offset from zero
+            * 4: Voltage amplitude
+            * 5: Frequency
+            * 6: Delay to start of sine wave
+            * 7: Damping factor
+            * 8: Phase delay
+            * 9: Frequency to use for harmonic balance analysis
 
         Returns
         -------
-
+        bool
+            ``True`` when successful, ``False`` when failed.
+        
         """
         id = self.create_unique_id()
 
@@ -948,16 +1037,16 @@ class NexximComponents(CircuitComponents):
                    "FDSFileName:=", "",
                    ["NAME:Properties",
                     "TextProp:=", ["LabelID","HD","Property string for netlist ID","V@ID"],
-                    "ValueProp:=", ["ACMAG","D","AC magnitude for small-signal analysis (Volts)",settings[0],0],
-                    "ValuePropNU:=", ["ACPHASE","D","AC phase for small-signal analysis",settings[1],0,"deg"],
-                    "ValueProp:=", ["DC","D","DC voltage (Volts)",settings[2],0],
+                    "ValueProp:=", ["ACMAG","OD","AC magnitude for small-signal analysis (Volts)",settings[0],0],
+                    "ValuePropNU:=", ["ACPHASE","OD","AC phase for small-signal analysis",settings[1],0,"deg"],
+                    "ValueProp:=", ["DC","OD","DC voltage (Volts)",settings[2],0],
                     "ValueProp:=", ["VO","OD","Voltage offset from zero (Volts)",settings[3],0],
                     "ValueProp:=", ["VA","OD","Voltage amplitude (Volts)",settings[4],0],
                     "ValueProp:=", ["FREQ","OD","Frequency (Hz)",settings[5],0],
-                    "ValueProp:=", ["TD","D","Delay to start of sine wave (seconds)",settings[6],0],
-                    "ValueProp:=", ["ALPHA","D","Damping factor (1/seconds)",settings[7],0],
-                    "ValuePropNU:=", ["THETA","D","Phase delay",settings[8],0,"deg"],
-                    "ValueProp:=", ["TONE","D","Frequency (Hz) to use for harmonic balance analysis, should be a submultiple of (or equal to) the driving frequency and should also be included in the HB analysis setup",settings[9],0],
+                    "ValueProp:=", ["TD","OD","Delay to start of sine wave (seconds)",settings[6],0],
+                    "ValueProp:=", ["ALPHA","OD","Damping factor (1/seconds)",settings[7],0],
+                    "ValuePropNU:=", ["THETA","OD","Phase delay",settings[8],0,"deg"],
+                    "ValueProp:=", ["TONE","OD","Frequency (Hz) to use for harmonic balance analysis, should be a submultiple of (or equal to) the driving frequency and should also be included in the HB analysis setup",settings[9],0],
                     "TextProp:=", ["ModelName","SHD","","V_SIN"],
                     "MenuProp:=", ["CoSimulator","D","","DefaultNetlist",0],
                     "ButtonProp:=", ["CosimDefinition","D","","","Edit",40501, "ButtonPropClientData:=", [] ] ] ] ] ] ]
@@ -976,4 +1065,4 @@ class NexximComponents(CircuitComponents):
 
         self._parent.odesign.UpdateSources(arg1,arg2)
 
-        pass
\ No newline at end of file
+        pass
