@@ -1,17 +1,5 @@
 """
-Mesh Library Class
-----------------------------------------------------------------
-
-
-Description
-==================================================
-
-This class contains all the functionalities to create and edit mesh in all the 3D Tools
-
-
-
-========================================================
-
+This module contains the `Mesh` class.
 """
 
 from __future__ import absolute_import
@@ -29,7 +17,19 @@ meshers = {"HFSS": "MeshSetup",
 
 
 class MeshOperation(object):
-    """ """
+    """MeshOperation class.
+    
+    Parameters
+    ----------
+    parent :
+    
+    name:
+    
+    props :
+    
+    meshoptpe :
+    
+    """
     def __init__(self, parent, name, props, meshoptype):
         self._parent = parent
         self.name = name
@@ -38,7 +38,7 @@ class MeshOperation(object):
 
     @aedt_exception_handler
     def _get_args(self):
-        """ """
+        """Retrieve arguments."""
         props = self.props
         arg = ["NAME:" + self.name]
         dict2arg(props, arg)
@@ -46,7 +46,13 @@ class MeshOperation(object):
 
     @aedt_exception_handler
     def create(self):
-        """ """
+        """Create a mesh.
+        
+        Returns
+        -------
+        type
+        
+        """
         if self.type == "SurfApproxBased":
             self._parent.omeshmodule.AssignTrueSurfOp(self._get_args())
         elif self.type == "DefeatureBased":
@@ -73,7 +79,14 @@ class MeshOperation(object):
 
     @aedt_exception_handler
     def update(self):
-        """ """
+        """Update the mesh.
+        
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+        
+        """
         if self.type == "SurfApproxBased":
             self._parent.omeshmodule.EditTrueSurfOp(self.name, self._get_args())
         elif self.type == "DefeatureBased":
@@ -100,7 +113,14 @@ class MeshOperation(object):
 
     @aedt_exception_handler
     def delete(self):
-        """ """
+        """Delete the mesh.
+        
+        Returns
+        -------
+        bool
+            ``True`` when successful, ``False`` when failed.
+        
+        """
         self._parent.omeshmodule.DeleteOp([self.name])
         for el in self._parent.meshoperations:
             if el.name == self.name:
@@ -109,17 +129,14 @@ class MeshOperation(object):
 
 
 class Mesh(object):
-    """""
-    Manage Main AEDT Mesh Functions
-    AEDTConfig Class Inherited contains all the _desktop Hierarchical calls needed to the class
-    ""
-
+    """Mesh class.   
+    
+    This class manages AEDT mesh functions.
+    
     Parameters
     ----------
-
-    Returns
-    -------
-
+    parent :
+    
     """
 
     def __init__(self, parent):
@@ -131,24 +148,24 @@ class Mesh(object):
 
     @property
     def omeshmodule(self):
-        """:return: Mesh Module"""
+        """Mesh module."""
         design_type = self.odesign.GetDesignType()
         assert design_type in meshers, "Invalid design type {}".format(design_type)
         return self.odesign.GetModule(meshers[design_type])
 
     @property
-    def messenger(self):
-        """ """
+    def _messenger(self):
+        """_messenger."""
         return self._parent._messenger
 
     @property
     def odesign(self):
-        """ """
+        """Design."""
         return self._parent._odesign
 
     @property
     def modeler(self):
-        """ """
+        """Modeler."""
         return self._parent._modeler
 
     @aedt_exception_handler
@@ -176,30 +193,31 @@ class Mesh(object):
 
     @aedt_exception_handler
     def assign_surface_mesh(self, names, level, meshop_name=None):
-        """Assign a predefined surface mesh level to an object
+        """Assign a surface mesh level to one or more objects.
 
         Parameters
         ----------
-        names :
-            name of the objects
-        level :
-            level of surface mesh
-        meshop_name :
-            optional name (Default value = None)
+        names : list
+            One or more names of the objects.
+        level : int
+            Level of the surface mesh. Options are ``1`` through ``10``
+        meshop_name : str, optional
+            Name of the mesh operation. The default is ``None``.
 
         Returns
         -------
-        type
-            meshoperation object
-
+        :class:`pyaedt.modules.Mesh.MeshOperation`
+            Mesh operation object.
+            
         """
+        names = self.modeler.convert_to_selections(names, True)
         if meshop_name:
             for m in self.meshoperations:
                 if meshop_name == m.name:
                     meshop_name = generate_unique_name(meshop_name)
         else:
             meshop_name = generate_unique_name("SurfApprox")
-        self.messenger.add_info_message("Assigning Mesh Level " + str(level) + " to " + str(names))
+        self._messenger.add_info_message("Assigning Mesh Level " + str(level) + " to " + str(names))
         names = self._parent._modeler._convert_list_to_ids(names)
 
         if type(names[0]) is int:
@@ -215,27 +233,28 @@ class Mesh(object):
 
     @aedt_exception_handler
     def assign_surface_mesh_manual(self, names, surf_dev=None, normal_dev=None, aspect_ratio=None, meshop_name=None):
-        """Assign Surface mesh to list of faces
+        """Assign a surface mesh to a list of faces.
 
         Parameters
         ----------
-        names :
-            list of objects to apply surface mesh
-        surf_dev :
-            float surface deviation (Default value = None)
-        normal_dev :
-            float normal deviation (Default value = None)
-        aspect_ratio :
-            int aspoect ration (Default value = None)
-        meshop_name :
-            label to apply to boundary (Default value = None)
+        names : list
+            List of faces to apply the surface mesh to.
+        surf_dev : float, optional
+            Surface deviation. The default is ``None``.
+        normal_dev : float, optional
+            Normal deviation. The default is ``None``.
+        aspect_ratio : int, optional
+            Aspect ratio. The default is ``None``.
+        meshop_name : str, optional
+            Name of the mesh operation. The default is ``None``.
 
         Returns
         -------
-        type
-            meshoperation object
-
+        :class:`pyaedt.modules.Mesh.MeshOperation`
+            Mesh operation object.
+            
         """
+        names = self.modeler.convert_to_selections(names, True)
         if meshop_name:
             for m in self.meshoperations:
                 if meshop_name == m.name:
@@ -272,30 +291,35 @@ class Mesh(object):
 
     @aedt_exception_handler
     def assign_model_resolution(self, names, defeature_length=None, meshop_name=None):
-        """Assign Model Resolution
+        """Assign the model resolution.
 
         Parameters
         ----------
-        names :
-            list of objects to defeature
-        defeature_length :
-            defeaturing length in mm. None for automatic defeature (Default value = None)
-        meshop_name :
-            optional name of meshoperation (Default value = None)
+        names : list
+            List of objects to defeature.
+        defeature_length : float, optional
+            Defeaturing length in millimeters. The default is ``None``, in which case 
+            automatic defeaturing is used.
+        meshop_name : str, optional
+            Name of the mesh operation. The default is ``None``.
 
         Returns
         -------
-        type
-            meshoperation object
-
+        :class:`pyaedt.modules.Mesh.MeshOperation`
+            Mesh operation object.
+        
         """
+        names = self.modeler.convert_to_selections(names, True)
         if meshop_name:
             for m in self.meshoperations:
                 if meshop_name == m.name:
                     meshop_name = generate_unique_name(meshop_name)
         else:
             meshop_name = generate_unique_name("ModelResolution")
-
+        for name in names:
+            if type(name) is int:
+                self._messenger.add_error_message("Mesh Operation Applies to Objects only")
+                return False
         if defeature_length is None:
             props = OrderedDict({"Objects": names, "UseAutoLength": True})
         else:
@@ -311,34 +335,38 @@ class Mesh(object):
     @aedt_exception_handler
     def assign_initial_mesh_from_slider(self, level=5, method='Auto', usedynamicsurface=True, useflexmesh=False,
                                         applycurvilinear=False, usefallback=True, usephi=True, automodelresolution=True, modelresolutionlength="0.0001mm"):
-        """Assign a predefined surface mesh level to an object
+        """Assign a surface mesh level to an object.
 
         Parameters
         ----------
-        level :
-            level of surface mesh (integer 1 - 10) (Default value = 5)
-        method :
-            mesher setting "Auto", "AnsoftTAU", "AnsoftClassic" (Default value = 'Auto')
-        usedynamicsurface :
-            Boolean (Default value = True)
-        useflexmesh :
-            Boolean (Default value = False)
-        applycurvilinear :
-            Boolean (Default value = False)
-        usefallback :
-            Boolean (Default value = True)
-        usephi :
-            Boolean (Default value = True)
-        automodelresolution :
-             (Default value = True)
-        modelresolutionlength :
-             (Default value = "0.0001mm")
+        level : int, optional
+            Level of the surface mesh. Options are ``1`` through ``10``. The default is ``5.``
+        method : str, optional
+            Meshing method. Options are ``"Auto"``, ``"AnsoftTAU"``, and ``"AnsoftClassic"`` 
+            The default is ``"Auto"``.
+        usedynamicsurface : bool, optional
+            Whether to use a dynamic surface. The default is ``True``.
+        useflexmesh : bool, optional
+            Whether to use a flexible mesh. The default is ``False``.
+        applycurvilinear : bool, optional
+            Whether to apply curvilinear elements. The default is ``False``.
+        usefallback : bool, optional
+            Whether to retain as a fallback. The default is ``True``.
+        usephi : bool, optional
+            Whether to use the Phi mesher for layered geometry. 
+            The default is ``True``.
+        automodelresolution : bool, optional
+            Whether to automatically calculate the resolution length
+            based on each object's effective thickness. The default is ``True``.  
+        modelresolutionlength : float, optional
+             Resolution thickness with units if ``automodelresolution=False``.
+             The default ``"0.0001mm"``.
 
         Returns
         -------
-        type
-            Boolean
-
+        bool
+            ``True`` when successful, ``False`` when failed.
+            
         """
         if self._parent.design_type == "2D Extractor" or self._parent.design_type == "Maxwell 2D":
             mesh_methods = ["Auto", "AnsoftClassic"]
@@ -368,20 +396,21 @@ class Mesh(object):
 
     @aedt_exception_handler
     def assign_surf_priority_for_tau(self, object_lists, surfpriority=0):
-        """Assign Surface Priority for Tau Mesheron object lists
+        """Assign a surface representation priority for the TAU mesh.
 
         Parameters
         ----------
-        object_lists :
-            list of objects to apply it
-        surfpriority :
-            int Surface Priority. Default 0
+        object_lists : list
+            List of objects to apply a surface representation
+            priority to.
+        surfpriority : int, optional
+            Surface representation priority. The default is ``0``.
 
         Returns
         -------
-        type
-            meshoperation object
-
+        :class:`pyaedt.modules.Mesh.MeshOperation`
+            Mesh operation object.
+        
         """
         meshop_name = generate_unique_name("SurfaceRepPriority")
         props = OrderedDict({"Type": "SurfaceRepPriority", "Objects": object_lists, "SurfaceRepPriority": surfpriority})
@@ -393,37 +422,37 @@ class Mesh(object):
 
     @aedt_exception_handler
     def generate_mesh(self, name):
-        """Generate Mesh for Setup name. Return 0 if mesh failed or 1 if passed
+        """Generate the mesh for a design.
 
         Parameters
         ----------
-        name :
-            name of design to be meshed
+        name : str
+            Name of the design.
 
         Returns
         -------
-        type
-            Bool
-
+        bool
+            ``True`` when successful, ``False`` when failed.
+            
         """
-
-        return self.odesign.GenerateMesh(name)
+        return self.odesign.GenerateMesh(name) == 0
 
 
     @aedt_exception_handler
     def delete_mesh_operations(self, mesh_type=None):
-        """Remove mesh operations from a design. If type is None, remove all mesh operations
+        """Remove mesh operations from a design. 
 
         Parameters
         ----------
-        mesh_type :
-            mesh operation type (Default value = None)
+        mesh_type : optional
+           Type of the mesh operation to delete. The default is ``None``, in which
+           case all mesh operations are deleted.
 
         Returns
         -------
-        type
-            Boolean
-
+        bool
+            ``True`` when successful, ``False`` when failed.
+        
         """
         # Type "Area Based" not included since the delete command causes
         # desktop to crash
@@ -448,27 +477,30 @@ class Mesh(object):
 
     @aedt_exception_handler
     def assign_length_mesh(self, names, isinside=True, maxlength=1, maxel=1000, meshop_name=None):
-        """
+        """Assign a length for the model resolution.
 
         Parameters
         ----------
-        names :
-            object lists. it can be a list of objects names or faces ids
-        isinside :
-            True if length mesh is inside selection, False if outside (Default value = True)
-        maxlength :
-            maxlength maximum element length. None to disable (Default value = 1)
-        maxel :
-            max number of element. None to disable (Default value = 1000)
-        meshop_name :
-            optional mesh operation name (Default value = None)
+        names : list
+            List of object names or face IDs.
+        isinside : bool, optional
+            Whether the length mesh is inside the selection. The default is ``True``.
+        maxlength : int, optional
+            Maximum element length. The default is ``1``. When ``None``, 
+            this parameter is disabled.
+        maxel : int, optional
+            Maximum number of elements. The default is ``1000``. When ``None``, this parameter
+            is disabled.
+        meshop_name : str, optional
+            Name of the mesh operation. The default is ``None``.
 
         Returns
         -------
-        type
-            meshoperation object
+        :class:`pyaedt.modules.Mesh.MeshOperation`
+            Mesh operation object.
 
         """
+        names = self.modeler.convert_to_selections(names, True)
         if meshop_name:
             for m in self.meshoperations:
                 if meshop_name == m.name:
@@ -489,7 +521,7 @@ class Mesh(object):
             restrictel = True
             numel = str(maxel)
         if maxlength is None and maxel is None:
-            self.messenger.add_error_message("mesh not assigned due to incorrect settings")
+            self._messenger.add_error_message("mesh not assigned due to incorrect settings")
             return
         names = self._parent._modeler._convert_list_to_ids(names)
 
@@ -500,7 +532,7 @@ class Mesh(object):
         else:
             seltype = None
         if seltype is None:
-            self.messenger.add_error_message("Error in Assignment")
+            self._messenger.add_error_message("Error in Assignment")
             return
         props = OrderedDict({"Type": "LengthBased", "RefineInside": isinside, "Enabled": True, seltype: names,
                              "RestrictElem": restrictel, "NumMaxElem": numel, "RestrictLength": restrictlength,
@@ -515,29 +547,33 @@ class Mesh(object):
     @aedt_exception_handler
     def assign_skin_depth(self, names, skindepth, maxelements=None, triangulation_max_length="0.1mm", numlayers="2",
                           meshop_name=None):
-        """
+        """Assign a skin depth for the mesh refinement.
 
         Parameters
         ----------
-        names :
-            object lists. it can be a list of objects names or faces ids
-        skindepth :
-            True if length mesh is inside selection, False if outside
-        maxelements :
-            maxlength maximum element length. None to disable (Default value = None)
-        triangulation_max_length :
-            maximum surface triangulation length (Default value = "0.1mm")
-        numlayers :
-            number of layers (Default value = "2")
-        meshop_name :
-             (Default value = None)
+        names : list
+           List of the object names or face IDs.
+        skindepth : bool
+            Whether the length mesh is inside the selection. The default is ``True``. 
+        maxelements : int, optional
+            Maximum number of elements. The default is ``None``, which means
+            this parameter is disabled.
+        triangulation_max_length : str, optional
+            Maximum surface triangulation length with units. The default 
+            is ``"0.1mm"`.
+        numlayers : str, optional
+            Number of layers. The default is ``"2"``.
+        meshop_name : str, optional
+            Name of the mesh operation. The default is ``None``.
 
         Returns
         -------
-        type
-            meshoperation object
-
+        :class:`pyaedt.modules.Mesh.MeshOperation`
+            Mesh operation object.
+            
         """
+        names = self.modeler.convert_to_selections(names, True)
+
         if self._parent.design_type != "HFSS" and self._parent.design_type != "Maxwell 3D":
             raise MethodNotSupportedError
         if meshop_name:
@@ -561,7 +597,7 @@ class Mesh(object):
         else:
             seltype = None
         if seltype is None:
-            self.messenger.add_error_message("Error in Assignment")
+            self._messenger.add_error_message("Error in Assignment")
             return
 
         props = OrderedDict({"Type": "SkinDepthBased", "Enabled": True, seltype: names,
@@ -575,24 +611,26 @@ class Mesh(object):
 
 
     @aedt_exception_handler
-    def appy_curvilinear_elements(self, names, enable=True, meshop_name=None):
-        """
+    def assign_curvilinear_elements(self, names, enable=True, meshop_name=None):
+        """Assign curvilinear elements.
 
         Parameters
         ----------
-        names :
-            object lists. it can be a list of objects or faces
-        enable :
-            True if enabled (Default value = True)
-        meshop_name :
-            optional mesh operation name (Default value = None)
+        names : list
+            List of objects or faces.
+        enable : bool, optional
+            Whether to apply curvilinear elements. The default is ``True``.
+         meshop_name : str, optional
+            Name of the mesh operation. The default is ``None``.
 
         Returns
         -------
-        type
-            meshoperation object
-
+        :class:`pyaedt.modules.Mesh.MeshOperation`
+            Mesh operation object.
+            
         """
+        names = self.modeler.convert_to_selections(names, True)
+
         if self._parent.design_type != "HFSS" and self._parent.design_type != "Maxwell 3D":
             raise MethodNotSupportedError
         if meshop_name:
@@ -610,7 +648,7 @@ class Mesh(object):
         else:
             seltype = None
         if seltype is None:
-            self.messenger.add_error_message("Error in Assignment")
+            self._messenger.add_error_message("Error in Assignment")
             return
         props = OrderedDict({"Type": "Curvilinear", seltype: names, "Apply": enable})
         mop = MeshOperation(self, meshop_name, props, "Curvilinear")
@@ -620,24 +658,27 @@ class Mesh(object):
 
 
     @aedt_exception_handler
-    def appy_curvature_extraction(self, names, disable_for_faceted_surf=True, meshop_name=None):
-        """
+    def assign_curvature_extraction(self, names, disable_for_faceted_surf=True, meshop_name=None):
+        """Assign curvature extraction.
 
         Parameters
         ----------
-        names :
-            object lists. it can be a list of objects or faces
-        disable_for_faceted_surf :
-            True if enabled (Default value = True)
-        meshop_name :
-            optional mesh operation name (Default value = None)
+        names : list
+            List of objects or faces.
+        disable_for_faceted_surf : bool, optional
+            Whether curvature extraction is enabled for faceted surfaces. 
+            The default is ``True``.
+        meshop_name : str, optional
+            Name of the mesh operation. The default is ``None``.
 
         Returns
         -------
-        type
-            meshoperation object
-
+       :class:`pyaedt.modules.Mesh.MeshOperation`
+            Mesh operation object.
+        
         """
+        names = self.modeler.convert_to_selections(names, True)
+
         if self._parent.solution_type != "SBR+":
             raise MethodNotSupportedError
         if meshop_name:
@@ -654,7 +695,7 @@ class Mesh(object):
         else:
             seltype = None
         if seltype is None:
-            self.messenger.add_error_message("Error in Assignment")
+            self._messenger.add_error_message("Error in Assignment")
             return
         props = OrderedDict(
             {"Type": "CurvatureExtraction", seltype: names, "DisableForFacetedSurfaces": disable_for_faceted_surf})
@@ -666,25 +707,28 @@ class Mesh(object):
 
     @aedt_exception_handler
     def assign_rotational_layer(self, names, num_layers=3, total_thickness="1mm", meshop_name=None):
-        """
+        """Assign a rotational layer mesh.
 
         Parameters
         ----------
-        names :
-            object lists.
-        num_layers :
-            str or int (Default value = 3)
-        total_thickness :
-            thickness with units (Default value = "1mm")
-        meshop_name :
-            optional mesh operation name (Default value = None)
+        names : list
+            List of objects.
+        num_layers : int, optional
+            Number of layers to create in the radial direction, starting from
+            the faces most adjacent to the band. The default is ``3``, which is the maximum.
+        total_thickness : str, optional
+            Total thickness of all layers with units. The default is ``"1mm"``.
+        meshop_name : str, optional
+            Name of the mesh operation. The default is ``None``.
 
         Returns
         -------
-        type
-            meshoperation object
-
+        :class:`pyaedt.modules.Mesh.MeshOperation`
+            Mesh operation object.
+            
         """
+        names = self.modeler.convert_to_selections(names, True)
+
         if self._parent.design_type != "Maxwell 3D":
             raise MethodNotSupportedError
         if meshop_name:
@@ -705,23 +749,25 @@ class Mesh(object):
 
     @aedt_exception_handler
     def assign_edge_cut(self, names, layer_thickness="1mm", meshop_name=None):
-        """
+        """Assign an edge cut layer mesh.
 
         Parameters
         ----------
-        names :
-            object lists.
+        names : list
+            List of objects.
         layer_thickness :
-            thickness with units (Default value = "1mm")
-        meshop_name :
-            optional mesh operation name (Default value = None)
+            Thickness of the layer with units. The default is ``"1mm"``.
+        meshop_name : str, optional
+            Name of the mesh operation. The default is ``None``.
 
         Returns
         -------
-        type
-            meshoperation object
-
+        :class:`pyaedt.modules.Mesh.MeshOperation`
+            Mesh operation object.
+            
         """
+        names = self.modeler.convert_to_selections(names, True)
+
         if self._parent.design_type != "Maxwell 3D":
             raise MethodNotSupportedError
         if meshop_name:
@@ -741,27 +787,31 @@ class Mesh(object):
 
     @aedt_exception_handler
     def assign_density_control(self, names, refine_inside=True, maxelementlength=None, layerNum=None, meshop_name=None):
-        """
+        """Assign density control.
 
         Parameters
         ----------
-        names :
-            object lists.
-        refine_inside :
-            Boolean (Default value = True)
-        maxelementlength :
-            dim with units. None to disable (Default value = None)
-        layerNum :
-            Number. None to disable (Default value = None)
-        meshop_name :
-            optional mesh operation name (Default value = None)
+        names : list
+            List of objects.
+        refine_inside : bool, optional
+            Whether to refine inside objects. The default is ``True``.
+        maxelementlength : str, optional
+            Maximum element length with units. The default is ``None``,
+            which disables this parameter.
+        layerNum : int, optional
+            Number of layers. The default is ``None``, which disables
+            this parameter.
+        meshop_name : str, optional
+            Name of the mesh operation. The default is ``None``.
 
         Returns
         -------
-        type
-            meshoperation object
-
+        :class:`pyaedt.modules.Mesh.MeshOperation`
+            Mesh operation object.
+            
         """
+        names = self.modeler.convert_to_selections(names, True)
+
         if self._parent.design_type != "Maxwell 3D":
             raise MethodNotSupportedError
         if meshop_name:
