@@ -1,25 +1,5 @@
-"""
-Simplorer Class
-----------------------------------------------------------------
+"""This module contains the `Simplorer` class."""
 
-This class contains all Simplorer functionalities.
-
-
-Examples:
-
-app = Simplorer()     Creates a ``Simplorer`` object and connects to an existing Maxwell design or cceates a new Maxwell design if one is not present.
-
-
-app = Simplorer(projectname)     Creates a ``Simplorer`` object and links to a project named projectname.
-
-
-app = Simplorer(projectname,designame)     Creates a ``Simplorer`` object and links to a design named designname in a project named projectname.
-
-
-app = Simplorer("myfile.aedt")     Creates a ``Simplorer`` object and opens the specified project.
-
-
-"""
 from __future__ import absolute_import
 
 import numbers
@@ -27,57 +7,101 @@ import numbers
 from .application.AnalysisSimplorer import FieldAnalysisSimplorer
 from .application.Variables import Variable
 from .desktop import exception_to_desktop
-from .generic.general_methods import aedt_exception_handler, generate_unique_name
+from .generic.general_methods import aedt_exception_handler, generate_unique_name, is_number
 
 
 class Simplorer(FieldAnalysisSimplorer, object):
-    """Simplorer Object
+    """Simplorer application interface.
 
     Parameters
     ----------
-    projectname :
-        name of the project to be selected or full path to the project to be opened  or to the AEDTZ
-        archive. if None try to get active project and, if nothing present to create an empty one
-    designname :
-        name of the design to be selected. if None, try to get active design and, if nothing present to create an empty one
-    solution_type :
-        solution type to be applied to design. if None default is taken
-    setup_name :
-        setup_name to be used as nominal. if none active setup is taken or nothing
+    projectname : str, optional
+        Name of the project to select or the full path to the project
+        or AEDTZ archive to open.  The default is ``None``, in which
+        case an attempt is made to get an active project. If no 
+        projects are present, an empty project is created.
+    designname : str, optional
+        Name of the design to select. The default is ``None``, in 
+        which case an attempt is made to get an active design. If no
+        designs are present, an empty design is created.
+    solution_type : str, optional
+        Solution type to apply to the design. The default is
+        ``None``, in which case the default type is applied.
+    setup_name : str, optional
+        Name of the setup to use as the nominal. The default is
+        ``None``, in which case the active setup is used or 
+        nothing is used.
+    specified_version : str, optional
+        Version of AEDT to use. The default is ``None``. If ``None``,
+        the active setup is used or the latest installed version is
+        used.
+    NG : bool, optional
+        Whether to launch AEDT in the non-graphical mode. The default
+        is ``False``, in which case AEDT is launched in the graphical mode.
+    AlwaysNew : bool, optional
+        Whether to launch an instance of AEDT in a new thread, even if
+        another instance of the ``specified_version`` is active on the
+        machine.  The default is ``True``.
+    release_on_exit : bool, optional
+        Whether to release AEDT on exit. The default is ``True``.
+    student_version : bool, optional
+        Whether open AEDT Student Version. The default is ``False``.
 
-    Returns
-    -------
+    Examples
+    --------
+    Create an instance of Simplorer and connect to an existing
+    Maxwell design or create a new Maxwell design if one does not
+    exist.
 
+    >>> from pyaedt import Simplorer
+    >>> app = Simplorer()
+
+    Create a instance of Simplorer and link to a project named
+    ``"projectname"``. If this project does not exist, create one with
+    this name.
+
+    >>> app = Simplorer(projectname)
+
+    Create an instance of Simplorer and link to a design named
+    ``"designname"`` in a project named ``"projectname"``.
+
+    >>> app = Simplorer(projectname, designame)
+
+    Create an instance of Simplorer and open the specified
+    project, which is named ``"myfile.aedt"``.
+
+    >>> app = Simplorer("myfile.aedt")
     """
 
-    def __init__(self, projectname=None, designname=None, solution_type=None, setup_name=None):
-        """
-        :param projectname: name of the project to be selected or full path to the project to be opened. if None try to
-         get active project and, if nothing present to create an empty one
-        :param designname: name of the design to be selected. if None, try to get active design and, if nothing present
-        to create an empty one
-        :param solution_type: solution type to be applied to design. if None default is taken
-        :param setup_name: setup_name to be used as nominal. if none active setup is taken or nothing
-        """
-        FieldAnalysisSimplorer.__init__(self, "Twin Builder", projectname, designname, solution_type, setup_name)
+    def __init__(self, projectname=None, designname=None, solution_type=None, setup_name=None,
+                 specified_version=None, NG=False, AlwaysNew=False, release_on_exit=False, student_version=False):
+        """Constructor."""
+        FieldAnalysisSimplorer.__init__(self, "Twin Builder", projectname, designname, solution_type, setup_name,
+                                        specified_version, NG, AlwaysNew, release_on_exit,student_version)
 
 
     @aedt_exception_handler
     def create_schematic_from_netlist(self, file_to_import):
-        """Create a Circuit Schematic from a spice netlist.
-        Supported in this moment:
-        -R, L, C, Diodes, Bjts
-        -Discrete components with syntax Uxxx net1 net2 ... netn modname
+        """Create a circuit schematic from an HSpice net list.
+        
+        Supported currently are:
+        
+        * R
+        * L
+        * C
+        * Diodes
+        * Bjts
+        * Discrete components with syntax ``Uxxx net1 net2 ... netn modname``
 
         Parameters
         ----------
-        file_to_import :
-            full path to spice file
+        file_to_import : str
+            Full path to the HSpice file.
 
         Returns
         -------
-        type
-            True if completed
+        bool
+            ``True`` when successful, ``False`` when failed.
 
         """
         xpos = 0
@@ -149,7 +173,7 @@ class Simplorer(FieldAnalysisSimplorer, object):
 
     @aedt_exception_handler
     def set_hmin(self, expression):
-        """
+        """Set hmin.
 
         Parameters
         ----------
@@ -158,6 +182,8 @@ class Simplorer(FieldAnalysisSimplorer, object):
 
         Returns
         -------
+        bool
+            ``True`` when successful, ``False`` when failed.
 
         """
         self.set_sim_setup_parameter('Hmin', expression)
@@ -165,7 +191,7 @@ class Simplorer(FieldAnalysisSimplorer, object):
 
     @aedt_exception_handler
     def set_hmax(self, expression):
-        """
+        """Set hmax.
 
         Parameters
         ----------
@@ -174,6 +200,8 @@ class Simplorer(FieldAnalysisSimplorer, object):
 
         Returns
         -------
+        bool
+            ``True`` when successful, ``False`` when failed.
 
         """
         self.set_sim_setup_parameter('Hmax', expression)
@@ -181,25 +209,27 @@ class Simplorer(FieldAnalysisSimplorer, object):
 
     @aedt_exception_handler
     def set_sim_setup_parameter(self, var_str, expression, analysis_name="TR"):
-        """
+        """Set simulation setup parameters.
 
         Parameters
         ----------
-        var_str :
-            
+        var_str : string
+            Name of the variable.   
         expression :
             
-        analysis_name :
-             (Default value = "TR")
+        analysis_name : str, optional
+             Name of the analysis. The default is ``"TR"``.
 
         Returns
         -------
+        bool
+            ``True`` when successful, ``False`` when failed.
 
         """
         if isinstance(expression, Variable):
             value_str = expression.string_value
         # Handle input type int/float, etc (including numeric 0)
-        elif isinstance(expression, numbers.Number):
+        elif is_number(expression):
             value_str = str(expression)
         else:
             value_str = expression
@@ -231,5 +261,3 @@ class Simplorer(FieldAnalysisSimplorer, object):
         """ Push exit up to parent object Design """
         if ex_type:
             exception_to_desktop(self, ex_value, ex_traceback)
-
-
